from delphixpy.web.objects.RunMaskingJobOnSourceOperation import RunMaskingJobOnSourceOperation
from delphixpy.web.objects.ToolkitLinkedStagedSource import ToolkitLinkedStagedSource
from delphixpy.web.objects.ContainerUtilizationInterval import ContainerUtilizationInterval
from delphixpy.web.objects.ASEBackupLocation import ASEBackupLocation
from delphixpy.web.objects.ReplicationSourceState import ReplicationSourceState
from delphixpy.web.objects.OracleLiveSource import OracleLiveSource
from delphixpy.web.objects.JSDataSourceCreateParameters import JSDataSourceCreateParameters
from delphixpy.web.objects.MSSqlLinkData import MSSqlLinkData
from delphixpy.web.objects.OracleDBConfigConnectivity import OracleDBConfigConnectivity
from delphixpy.web.objects.AbstractSourceConfigConnectivity import AbstractSourceConfigConnectivity
from delphixpy.web.objects.Action import Action
from delphixpy.web.objects.DspConnectivity import DspConnectivity
from delphixpy.web.objects.ASEDBConfig import ASEDBConfig
from delphixpy.web.objects.MSSqlDatabaseContainer import MSSqlDatabaseContainer
from delphixpy.web.objects.PgSQLDBContainerRuntime import PgSQLDBContainerRuntime
from delphixpy.web.objects.SchedulePolicy import SchedulePolicy
from delphixpy.web.objects.ChecklistItemDetail import ChecklistItemDetail
from delphixpy.web.objects.JSConfig import JSConfig
from delphixpy.web.objects.DetachSourceParameters import DetachSourceParameters
from delphixpy.web.objects.MSSqlRepository import MSSqlRepository
from delphixpy.web.objects.JSDataContainerActiveBranchParameters import JSDataContainerActiveBranchParameters
from delphixpy.web.objects.MSSqlFailoverClusterListener import MSSqlFailoverClusterListener
from delphixpy.web.objects.OracleDeleteParameters import OracleDeleteParameters
from delphixpy.web.objects.MSSqlSnapshotRuntime import MSSqlSnapshotRuntime
from delphixpy.web.objects.RefreshPolicy import RefreshPolicy
from delphixpy.web.objects.OraclePDBConfig import OraclePDBConfig
from delphixpy.web.objects.PgSQLDBClusterConfigConnectivity import PgSQLDBClusterConfigConnectivity
from delphixpy.web.objects.MSSqlCommvaultConfig import MSSqlCommvaultConfig
from delphixpy.web.objects.CreateTransformationParameters import CreateTransformationParameters
from delphixpy.web.objects.EngineAggregateIngestedSize import EngineAggregateIngestedSize
from delphixpy.web.objects.TimeflowRepairParameters import TimeflowRepairParameters
from delphixpy.web.objects.PgSQLLinkData import PgSQLLinkData
from delphixpy.web.objects.OracleBaseProvisionParameters import OracleBaseProvisionParameters
from delphixpy.web.objects.ASECreateTransformationParameters import ASECreateTransformationParameters
from delphixpy.web.objects.StorageDeviceInitializeStatus import StorageDeviceInitializeStatus
from delphixpy.web.objects.IntegerConstraint import IntegerConstraint
from delphixpy.web.objects.Domain import Domain
from delphixpy.web.objects.AppDataRepository import AppDataRepository
from delphixpy.web.objects.GetLogParameters import GetLogParameters
from delphixpy.web.objects.OracleSourceRuntime import OracleSourceRuntime
from delphixpy.web.objects.MySQLVirtualSource import MySQLVirtualSource
from delphixpy.web.objects.AndFilter import AndFilter
from delphixpy.web.objects.Statistic import Statistic
from delphixpy.web.objects.Permission import Permission
from delphixpy.web.objects.HostRuntime import HostRuntime
from delphixpy.web.objects.ASENewBackupSyncParameters import ASENewBackupSyncParameters
from delphixpy.web.objects.SeverityFilter import SeverityFilter
from delphixpy.web.objects.OracleCharacterSet import OracleCharacterSet
from delphixpy.web.objects.HostEnvironment import HostEnvironment
from delphixpy.web.objects.StorageTestResult import StorageTestResult
from delphixpy.web.objects.ChangeCurrentPasswordPolicyParameters import ChangeCurrentPasswordPolicyParameters
from delphixpy.web.objects.VMwareTimeflowPoint import VMwareTimeflowPoint
from delphixpy.web.objects.MSSqlFailoverClusterRepository import MSSqlFailoverClusterRepository
from delphixpy.web.objects.MSSqlExportParameters import MSSqlExportParameters
from delphixpy.web.objects.SshVerificationStrategy import SshVerificationStrategy
from delphixpy.web.objects.MySQLSnapshotRuntime import MySQLSnapshotRuntime
from delphixpy.web.objects.AppDataDirectLinkData import AppDataDirectLinkData
from delphixpy.web.objects.OracleTimeflowLog import OracleTimeflowLog
from delphixpy.web.objects.MSSqlBaseClusterInstance import MSSqlBaseClusterInstance
from delphixpy.web.objects.HostMachine import HostMachine
from delphixpy.web.objects.JSOperationEndpointParameters import JSOperationEndpointParameters
from delphixpy.web.objects.ProxyService import ProxyService
from delphixpy.web.objects.PgSQLCompatibilityCriteria import PgSQLCompatibilityCriteria
from delphixpy.web.objects.HistoricalConsumerCapacityData import HistoricalConsumerCapacityData
from delphixpy.web.objects.NetworkInterfaceUtilDatapointStream import NetworkInterfaceUtilDatapointStream
from delphixpy.web.objects.VMwareHostEnvironment import VMwareHostEnvironment
from delphixpy.web.objects.AddLiveSourceParameters import AddLiveSourceParameters
from delphixpy.web.objects.JSOperationEndpointBranchParameters import JSOperationEndpointBranchParameters
from delphixpy.web.objects.PgSQLInstall import PgSQLInstall
from delphixpy.web.objects.SsoConfig import SsoConfig
from delphixpy.web.objects.APIError import APIError
from delphixpy.web.objects.MySQLDatabaseContainer import MySQLDatabaseContainer
from delphixpy.web.objects.BaseGroupCapacityData import BaseGroupCapacityData
from delphixpy.web.objects.VfsOpsDatapointStream import VfsOpsDatapointStream
from delphixpy.web.objects.OracleClusterNodeCreateParameters import OracleClusterNodeCreateParameters
from delphixpy.web.objects.DxFsOpsDatapointStream import DxFsOpsDatapointStream
from delphixpy.web.objects.OracleFileSpecification import OracleFileSpecification
from delphixpy.web.objects.InterfaceAddress import InterfaceAddress
from delphixpy.web.objects.AppDataAdditionalMountPoint import AppDataAdditionalMountPoint
from delphixpy.web.objects.AppDataFilesystemLayout import AppDataFilesystemLayout
from delphixpy.web.objects.RefreshParameters import RefreshParameters
from delphixpy.web.objects.NotificationDrop import NotificationDrop
from delphixpy.web.objects.CipherSuite import CipherSuite
from delphixpy.web.objects.PgSQLSource import PgSQLSource
from delphixpy.web.objects.SshVerifyFingerprint import SshVerifyFingerprint
from delphixpy.web.objects.WindowsConnectivityParameters import WindowsConnectivityParameters
from delphixpy.web.objects.ReplicationObjectSpecification import ReplicationObjectSpecification
from delphixpy.web.objects.PgSQLSyncParameters import PgSQLSyncParameters
from delphixpy.web.objects.TimeflowPointSnapshot import TimeflowPointSnapshot
from delphixpy.web.objects.MSSqlSourceConnectionInfo import MSSqlSourceConnectionInfo
from delphixpy.web.objects.MSSqlExistingSpecificBackupSyncParameters import MSSqlExistingSpecificBackupSyncParameters
from delphixpy.web.objects.OracleDatafileTempfileSpecification import OracleDatafileTempfileSpecification
from delphixpy.web.objects.MySQLLinkedSource import MySQLLinkedSource
from delphixpy.web.objects.AppDataSourceConnectionInfo import AppDataSourceConnectionInfo
from delphixpy.web.objects.Alert import Alert
from delphixpy.web.objects.AuthorizationConfig import AuthorizationConfig
from delphixpy.web.objects.SystemPackage import SystemPackage
from delphixpy.web.objects.SourceConfig import SourceConfig
from delphixpy.web.objects.OracleSource import OracleSource
from delphixpy.web.objects.TimeflowSnapshotDayRange import TimeflowSnapshotDayRange
from delphixpy.web.objects.Log import Log
from delphixpy.web.objects.PasswordPolicy import PasswordPolicy
from delphixpy.web.objects.IoOpsDatapoint import IoOpsDatapoint
from delphixpy.web.objects.NetworkThroughputTestBase import NetworkThroughputTestBase
from delphixpy.web.objects.OracleVirtualSource import OracleVirtualSource
from delphixpy.web.objects.ApplyVersionParameters import ApplyVersionParameters
from delphixpy.web.objects.AppDataSyncParameters import AppDataSyncParameters
from delphixpy.web.objects.ResolveOrIgnoreSelectedFaultsParameters import ResolveOrIgnoreSelectedFaultsParameters
from delphixpy.web.objects.JSTimelinePointLatestTimeInput import JSTimelinePointLatestTimeInput
from delphixpy.web.objects.EndEntity import EndEntity
from delphixpy.web.objects.SourceOperation import SourceOperation
from delphixpy.web.objects.TimeflowPointParameters import TimeflowPointParameters
from delphixpy.web.objects.MySQLExistingMySQLDumpSyncParameters import MySQLExistingMySQLDumpSyncParameters
from delphixpy.web.objects.BaseSupportBundleParameters import BaseSupportBundleParameters
from delphixpy.web.objects.OracleVirtualCdbProvisionParameters import OracleVirtualCdbProvisionParameters
from delphixpy.web.objects.OraclePDBSourceRuntime import OraclePDBSourceRuntime
from delphixpy.web.objects.MSSqlInstance import MSSqlInstance
from delphixpy.web.objects.NetworkRoute import NetworkRoute
from delphixpy.web.objects.Policy import Policy
from delphixpy.web.objects.OracleVirtualPdbSource import OracleVirtualPdbSource
from delphixpy.web.objects.SyncParameters import SyncParameters
from delphixpy.web.objects.ASESyncParameters import ASESyncParameters
from delphixpy.web.objects.XppValidateStatus import XppValidateStatus
from delphixpy.web.objects.SourceEnvironmentCreateParameters import SourceEnvironmentCreateParameters
from delphixpy.web.objects.PopulateCompatibilityParameters import PopulateCompatibilityParameters
from delphixpy.web.objects.OracleTempfileSpecification import OracleTempfileSpecification
from delphixpy.web.objects.JSDataLayout import JSDataLayout
from delphixpy.web.objects.MySQLExistingBackupSyncParameters import MySQLExistingBackupSyncParameters
from delphixpy.web.objects.ProxyConfiguration import ProxyConfiguration
from delphixpy.web.objects.BooleanConstraint import BooleanConstraint
from delphixpy.web.objects.SwitchSessionUserParameters import SwitchSessionUserParameters
from delphixpy.web.objects.WindowsCluster import WindowsCluster
from delphixpy.web.objects.ASEDBContainerRuntime import ASEDBContainerRuntime
from delphixpy.web.objects.ChecklistItem import ChecklistItem
from delphixpy.web.objects.ToolkitLinkedDirectSource import ToolkitLinkedDirectSource
from delphixpy.web.objects.HttpConnectorConfig import HttpConnectorConfig
from delphixpy.web.objects.Toolkit import Toolkit
from delphixpy.web.objects.ContainerUtilization import ContainerUtilization
from delphixpy.web.objects.SnapshotSpaceParameters import SnapshotSpaceParameters
from delphixpy.web.objects.AlertActionEmailList import AlertActionEmailList
from delphixpy.web.objects.SourceConfigConnectivity import SourceConfigConnectivity
from delphixpy.web.objects.EnvironmentUser import EnvironmentUser
from delphixpy.web.objects.ASEPlatformParameters import ASEPlatformParameters
from delphixpy.web.objects.OracleDatabaseStatsSection import OracleDatabaseStatsSection
from delphixpy.web.objects.XPPCompatibilityParameters import XPPCompatibilityParameters
from delphixpy.web.objects.BasePlatformParameters import BasePlatformParameters
from delphixpy.web.objects.OracleCustomEnvVarSIPair import OracleCustomEnvVarSIPair
from delphixpy.web.objects.SshAcceptAlways import SshAcceptAlways
from delphixpy.web.objects.HostPrivilegeElevationProfile import HostPrivilegeElevationProfile
from delphixpy.web.objects.HostCreateParameters import HostCreateParameters
from delphixpy.web.objects.NetworkTestParameters import NetworkTestParameters
from delphixpy.web.objects.MSSqlVirtualSource import MSSqlVirtualSource
from delphixpy.web.objects.OracleSystemDatafileSpecification import OracleSystemDatafileSpecification
from delphixpy.web.objects.FractionPlugParameters import FractionPlugParameters
from delphixpy.web.objects.SourceRuntime import SourceRuntime
from delphixpy.web.objects.OracleVirtualCdbSource import OracleVirtualCdbSource
from delphixpy.web.objects.PublicKeyCredential import PublicKeyCredential
from delphixpy.web.objects.DSPBestParameters import DSPBestParameters
from delphixpy.web.objects.EmptyDatasetCreationParameters import EmptyDatasetCreationParameters
from delphixpy.web.objects.RegistrationParameters import RegistrationParameters
from delphixpy.web.objects.MSSqlAvailabilityGroup import MSSqlAvailabilityGroup
from delphixpy.web.objects.VMwareSourceConnectionInfo import VMwareSourceConnectionInfo
from delphixpy.web.objects.AppDataProvisionParameters import AppDataProvisionParameters
from delphixpy.web.objects.MSSqlExistingBackupSyncParameters import MSSqlExistingBackupSyncParameters
from delphixpy.web.objects.JSBranchCreateParameters import JSBranchCreateParameters
from delphixpy.web.objects.OracleEnableParameters import OracleEnableParameters
from delphixpy.web.objects.PluginLinkedSourceDefinition import PluginLinkedSourceDefinition
from delphixpy.web.objects.BaseSystemCapacityData import BaseSystemCapacityData
from delphixpy.web.objects.JSOperationEndpointDataLayoutParameters import JSOperationEndpointDataLayoutParameters
from delphixpy.web.objects.DataResult import DataResult
from delphixpy.web.objects.SourceRepositoryTemplate import SourceRepositoryTemplate
from delphixpy.web.objects.TimeflowRangeParameters import TimeflowRangeParameters
from delphixpy.web.objects.PreProvisioningRuntime import PreProvisioningRuntime
from delphixpy.web.objects.PgSQLDatabaseTemplate import PgSQLDatabaseTemplate
from delphixpy.web.objects.StatisticEnumAxis import StatisticEnumAxis
from delphixpy.web.objects.ASESnapshotRuntime import ASESnapshotRuntime
from delphixpy.web.objects.CreateMaskingJobTransformationParameters import CreateMaskingJobTransformationParameters
from delphixpy.web.objects.ASEHostEnvironmentParameters import ASEHostEnvironmentParameters
from delphixpy.web.objects.IntegerLessThanConstraint import IntegerLessThanConstraint
from delphixpy.web.objects.MSSqlSource import MSSqlSource
from delphixpy.web.objects.TimeflowPointBookmarkTag import TimeflowPointBookmarkTag
from delphixpy.web.objects.VMwareHost import VMwareHost
from delphixpy.web.objects.AlertActionEmail import AlertActionEmail
from delphixpy.web.objects.TimeRangeParameters import TimeRangeParameters
from delphixpy.web.objects.JSDataContainerDeleteParameters import JSDataContainerDeleteParameters
from delphixpy.web.objects.HostOS import HostOS
from delphixpy.web.objects.PathConstraint import PathConstraint
from delphixpy.web.objects.ProvisionParameters import ProvisionParameters
from delphixpy.web.objects.StorageDeviceRemovalVerifyResult import StorageDeviceRemovalVerifyResult
from delphixpy.web.objects.Datapoint import Datapoint
from delphixpy.web.objects.SNMPConfig import SNMPConfig
from delphixpy.web.objects.AppDataTimeflow import AppDataTimeflow
from delphixpy.web.objects.SourceTypeAggregateIngestedSize import SourceTypeAggregateIngestedSize
from delphixpy.web.objects.FilesystemLayout import FilesystemLayout
from delphixpy.web.objects.PgSQLStagingSource import PgSQLStagingSource
from delphixpy.web.objects.SMTPConfig import SMTPConfig
from delphixpy.web.objects.User import User
from delphixpy.web.objects.MSSqlSIConfig import MSSqlSIConfig
from delphixpy.web.objects.X509Certificate import X509Certificate
from delphixpy.web.objects.JSTimelinePointBookmarkInput import JSTimelinePointBookmarkInput
from delphixpy.web.objects.Namespace import Namespace
from delphixpy.web.objects.MSSqlSourceRuntime import MSSqlSourceRuntime
from delphixpy.web.objects.JSDataContainerCreateWithoutRefreshParameters import JSDataContainerCreateWithoutRefreshParameters
from delphixpy.web.objects.JSBranchUsageData import JSBranchUsageData
from delphixpy.web.objects.SourcingPolicy import SourcingPolicy
from delphixpy.web.objects.OracleInstall import OracleInstall
from delphixpy.web.objects.DatabaseTemplateConfig import DatabaseTemplateConfig
from delphixpy.web.objects.SupportAccessState import SupportAccessState
from delphixpy.web.objects.JSWeeklyOperationCount import JSWeeklyOperationCount
from delphixpy.web.objects.CompatibleRepositoriesParameters import CompatibleRepositoriesParameters
from delphixpy.web.objects.NotFilter import NotFilter
from delphixpy.web.objects.EndEntityCertificateReplaceChainParameters import EndEntityCertificateReplaceChainParameters
from delphixpy.web.objects.PurgeLogsParameters import PurgeLogsParameters
from delphixpy.web.objects.RunCommandOnSourceOperation import RunCommandOnSourceOperation
from delphixpy.web.objects.PgSQLDBClusterConfig import PgSQLDBClusterConfig
from delphixpy.web.objects.SnapshotSpaceResult import SnapshotSpaceResult
from delphixpy.web.objects.NetworkThroughputTestBaseParameters import NetworkThroughputTestBaseParameters
from delphixpy.web.objects.OperationTemplate import OperationTemplate
from delphixpy.web.objects.JDBCConnectivity import JDBCConnectivity
from delphixpy.web.objects.LdapServer import LdapServer
from delphixpy.web.objects.ASEVirtualSource import ASEVirtualSource
from delphixpy.web.objects.MSSqlFailoverClusterDBConfig import MSSqlFailoverClusterDBConfig
from delphixpy.web.objects.IScsiOpsDatapointStream import IScsiOpsDatapointStream
from delphixpy.web.objects.OracleLinkData import OracleLinkData
from delphixpy.web.objects.NetworkInterface import NetworkInterface
from delphixpy.web.objects.MySQLReplicationCoordinates import MySQLReplicationCoordinates
from delphixpy.web.objects.OracleExportParameters import OracleExportParameters
from delphixpy.web.objects.OracleActiveInstance import OracleActiveInstance
from delphixpy.web.objects.AuthFilterParameters import AuthFilterParameters
from delphixpy.web.objects.ConfiguredStorageDevice import ConfiguredStorageDevice
from delphixpy.web.objects.SyslogConfig import SyslogConfig
from delphixpy.web.objects.AlertActionEmailUser import AlertActionEmailUser
from delphixpy.web.objects.CpuUtilDatapointStream import CpuUtilDatapointStream
from delphixpy.web.objects.MySQLSourceConnectionInfo import MySQLSourceConnectionInfo
from delphixpy.web.objects.ASECompatibilityCriteria import ASECompatibilityCriteria
from delphixpy.web.objects.NamedUserObject import NamedUserObject
from delphixpy.web.objects.AxisConstraint import AxisConstraint
from delphixpy.web.objects.PgSQLDatabaseContainer import PgSQLDatabaseContainer
from delphixpy.web.objects.OracleStagingSource import OracleStagingSource
from delphixpy.web.objects.ASEAttachData import ASEAttachData
from delphixpy.web.objects.EndEntityDsp import EndEntityDsp
from delphixpy.web.objects.MSSqlTimeflowPoint import MSSqlTimeflowPoint
from delphixpy.web.objects.SamlInfo import SamlInfo
from delphixpy.web.objects.AbstractToolkit import AbstractToolkit
from delphixpy.web.objects.CommvaultConnectivityParameters import CommvaultConnectivityParameters
from delphixpy.web.objects.StorageTest import StorageTest
from delphixpy.web.objects.PluginLinkedDirectSourceDefinition import PluginLinkedDirectSourceDefinition
from delphixpy.web.objects.CurrentConsumerCapacityData import CurrentConsumerCapacityData
from delphixpy.web.objects.Checklist import Checklist
from delphixpy.web.objects.OracleSnapshotRuntime import OracleSnapshotRuntime
from delphixpy.web.objects.NetworkRouteLookupParameters import NetworkRouteLookupParameters
from delphixpy.web.objects.ReplicationSpec import ReplicationSpec
from delphixpy.web.objects.CompatibleRepositoriesResult import CompatibleRepositoriesResult
from delphixpy.web.objects.JSBookmark import JSBookmark
from delphixpy.web.objects.FileMappingParameters import FileMappingParameters
from delphixpy.web.objects.AppDataContainerRuntime import AppDataContainerRuntime
from delphixpy.web.objects.OracleBaseSourceRuntime import OracleBaseSourceRuntime
from delphixpy.web.objects.OracleTimeflowPoint import OracleTimeflowPoint
from delphixpy.web.objects.ExternalBackupIngestionStrategy import ExternalBackupIngestionStrategy
from delphixpy.web.objects.OracleSourcingPolicy import OracleSourcingPolicy
from delphixpy.web.objects.EndEntityHttps import EndEntityHttps
from delphixpy.web.objects.MySQLCompatibilityCriteria import MySQLCompatibilityCriteria
from delphixpy.web.objects.UserObject import UserObject
from delphixpy.web.objects.OracleMultitenantProvisionParameters import OracleMultitenantProvisionParameters
from delphixpy.web.objects.WindowsHostCreateParameters import WindowsHostCreateParameters
from delphixpy.web.objects.OracleSISourceConnectionInfo import OracleSISourceConnectionInfo
from delphixpy.web.objects.MSSqlFailoverClusterDriveLetter import MSSqlFailoverClusterDriveLetter
from delphixpy.web.objects.Notification import Notification
from delphixpy.web.objects.PgSQLSnapshot import PgSQLSnapshot
from delphixpy.web.objects.MySQLGtidCoordinates import MySQLGtidCoordinates
from delphixpy.web.objects.VMwareLinkData import VMwareLinkData
from delphixpy.web.objects.OracleBaseDBConfig import OracleBaseDBConfig
from delphixpy.web.objects.DelphixDataServicesComponentInfo import DelphixDataServicesComponentInfo
from delphixpy.web.objects.MSSqlLinkedSource import MSSqlLinkedSource
from delphixpy.web.objects.PluginUpgradeDefinition import PluginUpgradeDefinition
from delphixpy.web.objects.Transformation import Transformation
from delphixpy.web.objects.SourceIngestionData import SourceIngestionData
from delphixpy.web.objects.SnapshotRuntime import SnapshotRuntime
from delphixpy.web.objects.MSSqlNetbackupConfig import MSSqlNetbackupConfig
from delphixpy.web.objects.JSBookmarkUsageData import JSBookmarkUsageData
from delphixpy.web.objects.FileProcessingResult import FileProcessingResult
from delphixpy.web.objects.MSSqlCreateTransformationParameters import MSSqlCreateTransformationParameters
from delphixpy.web.objects.PgSQLProvisionParameters import PgSQLProvisionParameters
from delphixpy.web.objects.PemCertificate import PemCertificate
from delphixpy.web.objects.OracleCustomEnvVarSIFile import OracleCustomEnvVarSIFile
from delphixpy.web.objects.APIVersion import APIVersion
from delphixpy.web.objects.ValidateJavaParameters import ValidateJavaParameters
from delphixpy.web.objects.LogFetchSSH import LogFetchSSH
from delphixpy.web.objects.MySQLStagingSource import MySQLStagingSource
from delphixpy.web.objects.PgSQLVirtualSource import PgSQLVirtualSource
from delphixpy.web.objects.FileUploadResult import FileUploadResult
from delphixpy.web.objects.ASESource import ASESource
from delphixpy.web.objects.NfsOpsDatapointStream import NfsOpsDatapointStream
from delphixpy.web.objects.Certificate import Certificate
from delphixpy.web.objects.MySQLProvisionParameters import MySQLProvisionParameters
from delphixpy.web.objects.DeleteParameters import DeleteParameters
from delphixpy.web.objects.OracleLiveSourceRuntime import OracleLiveSourceRuntime
from delphixpy.web.objects.OracleRedoLogFileSpecification import OracleRedoLogFileSpecification
from delphixpy.web.objects.OracleCustomEnvVarRACPair import OracleCustomEnvVarRACPair
from delphixpy.web.objects.SystemKeyCredential import SystemKeyCredential
from delphixpy.web.objects.IngestionStrategy import IngestionStrategy
from delphixpy.web.objects.Job import Job
from delphixpy.web.objects.PersistentObject import PersistentObject
from delphixpy.web.objects.AttachData import AttachData
from delphixpy.web.objects.PublicSystemInfo import PublicSystemInfo
from delphixpy.web.objects.AppDataSourceRuntime import AppDataSourceRuntime
from delphixpy.web.objects.GlobalLinkingSettings import GlobalLinkingSettings
from delphixpy.web.objects.WindowsClusterNode import WindowsClusterNode
from delphixpy.web.objects.DSPOptions import DSPOptions
from delphixpy.web.objects.MySQLPlatformParameters import MySQLPlatformParameters
from delphixpy.web.objects.PgSQLSourceConnectionInfo import PgSQLSourceConnectionInfo
from delphixpy.web.objects.HostConfiguration import HostConfiguration
from delphixpy.web.objects.OracleRollbackParameters import OracleRollbackParameters
from delphixpy.web.objects.JSDataContainerResetParameters import JSDataContainerResetParameters
from delphixpy.web.objects.DBContainerRuntime import DBContainerRuntime
from delphixpy.web.objects.XppStatus import XppStatus
from delphixpy.web.objects.CertificateFetchParameters import CertificateFetchParameters
from delphixpy.web.objects.JSBookmarkTagUsageData import JSBookmarkTagUsageData
from delphixpy.web.objects.RunPowerShellOnSourceOperation import RunPowerShellOnSourceOperation
from delphixpy.web.objects.MaskingJob import MaskingJob
from delphixpy.web.objects.SystemInitializationParameters import SystemInitializationParameters
from delphixpy.web.objects.OKResult import OKResult
from delphixpy.web.objects.DatabaseContainer import DatabaseContainer
from delphixpy.web.objects.UpTimeInfo import UpTimeInfo
from delphixpy.web.objects.OracleScanListener import OracleScanListener
from delphixpy.web.objects.KeyPairCredential import KeyPairCredential
from delphixpy.web.objects.OracleDatabaseStatistic import OracleDatabaseStatistic
from delphixpy.web.objects.Credential import Credential
from delphixpy.web.objects.WindowsHostEnvironment import WindowsHostEnvironment
from delphixpy.web.objects.OracleDatabaseContainer import OracleDatabaseContainer
from delphixpy.web.objects.TargetFilter import TargetFilter
from delphixpy.web.objects.JSSourceDataTimestampParameters import JSSourceDataTimestampParameters
from delphixpy.web.objects.JSDataContainer import JSDataContainer
from delphixpy.web.objects.OracleDBConfig import OracleDBConfig
from delphixpy.web.objects.JSTimelinePointParameters import JSTimelinePointParameters
from delphixpy.web.objects.ASELatestBackupSyncParameters import ASELatestBackupSyncParameters
from delphixpy.web.objects.TCPStatsDatapointStream import TCPStatsDatapointStream
from delphixpy.web.objects.MySQLCreateTransformationParameters import MySQLCreateTransformationParameters
from delphixpy.web.objects.OracleFetchedLog import OracleFetchedLog
from delphixpy.web.objects.Fault import Fault
from delphixpy.web.objects.MSSqlAvailabilityGroupDBConfig import MSSqlAvailabilityGroupDBConfig
from delphixpy.web.objects.JSBookmarkCheckoutCount import JSBookmarkCheckoutCount
from delphixpy.web.objects.SystemVersion import SystemVersion
from delphixpy.web.objects.SsoSuccessfulLoginRecord import SsoSuccessfulLoginRecord
from delphixpy.web.objects.UnixHostEnvironment import UnixHostEnvironment
from delphixpy.web.objects.UserAuthInfo import UserAuthInfo
from delphixpy.web.objects.AppDataExportParameters import AppDataExportParameters
from delphixpy.web.objects.DiskOpsDatapointStream import DiskOpsDatapointStream
from delphixpy.web.objects.AppDataVirtualSource import AppDataVirtualSource
from delphixpy.web.objects.TimeflowRepairSSH import TimeflowRepairSSH
from delphixpy.web.objects.MySQLAttachData import MySQLAttachData
from delphixpy.web.objects.XppLastRunStatus import XppLastRunStatus
from delphixpy.web.objects.CaCertificate import CaCertificate
from delphixpy.web.objects.ToolkitLocale import ToolkitLocale
from delphixpy.web.objects.EnumEqualConstraint import EnumEqualConstraint
from delphixpy.web.objects.RunExpectOnSourceOperation import RunExpectOnSourceOperation
from delphixpy.web.objects.Role import Role
from delphixpy.web.objects.NetworkThroughputTest import NetworkThroughputTest
from delphixpy.web.objects.NTPConfig import NTPConfig
from delphixpy.web.objects.OracleDisableParameters import OracleDisableParameters
from delphixpy.web.objects.ASELinkData import ASELinkData
from delphixpy.web.objects.DelphixManagedBackupIngestionStrategy import DelphixManagedBackupIngestionStrategy
from delphixpy.web.objects.SSHConnectivity import SSHConnectivity
from delphixpy.web.objects.MSSqlPlatformParameters import MSSqlPlatformParameters
from delphixpy.web.objects.NetworkThroughputTestParameters import NetworkThroughputTestParameters
from delphixpy.web.objects.Plugin import Plugin
from delphixpy.web.objects.AppDataStagedSourceConfig import AppDataStagedSourceConfig
from delphixpy.web.objects.Host import Host
from delphixpy.web.objects.Authorization import Authorization
from delphixpy.web.objects.JSUserUsageData import JSUserUsageData
from delphixpy.web.objects.SNMPManager import SNMPManager
from delphixpy.web.objects.JobEvent import JobEvent
from delphixpy.web.objects.OracleDatabaseCreationParameters import OracleDatabaseCreationParameters
from delphixpy.web.objects.MySQLServerConfig import MySQLServerConfig
from delphixpy.web.objects.X500DistinguishedName import X500DistinguishedName
from delphixpy.web.objects.LinkedSourceOperations import LinkedSourceOperations
from delphixpy.web.objects.JSDataContainerModifyOwnerParameters import JSDataContainerModifyOwnerParameters
from delphixpy.web.objects.ASESIConfig import ASESIConfig
from delphixpy.web.objects.ASESpecificBackupSyncParameters import ASESpecificBackupSyncParameters
from delphixpy.web.objects.MySQLSource import MySQLSource
from delphixpy.web.objects.AppDataSnapshot import AppDataSnapshot
from delphixpy.web.objects.CallResult import CallResult
from delphixpy.web.objects.XppStagingStatus import XppStagingStatus
from delphixpy.web.objects.PgSQLTimeflow import PgSQLTimeflow
from delphixpy.web.objects.OracleExport import OracleExport
from delphixpy.web.objects.OracleClusterCreateParameters import OracleClusterCreateParameters
from delphixpy.web.objects.PluginVirtualSourceDefinition import PluginVirtualSourceDefinition
from delphixpy.web.objects.JSDataTemplate import JSDataTemplate
from delphixpy.web.objects.HostEnvironmentCreateParameters import HostEnvironmentCreateParameters
from delphixpy.web.objects.GetCurrentPasswordPolicyParameters import GetCurrentPasswordPolicyParameters
from delphixpy.web.objects.MigrateCompatibilityParameters import MigrateCompatibilityParameters
from delphixpy.web.objects.UnixConnectivityParameters import UnixConnectivityParameters
from delphixpy.web.objects.JSBranch import JSBranch
from delphixpy.web.objects.JSUsageData import JSUsageData
from delphixpy.web.objects.UnixHost import UnixHost
from delphixpy.web.objects.FileDownloadResult import FileDownloadResult
from delphixpy.web.objects.FaultResolveParameters import FaultResolveParameters
from delphixpy.web.objects.ASEProvisionParameters import ASEProvisionParameters
from delphixpy.web.objects.MSSqlSnapshot import MSSqlSnapshot
from delphixpy.web.objects.BooleanEqualConstraint import BooleanEqualConstraint
from delphixpy.web.objects.MSSqlLinkedSourceUpgradeParameters import MSSqlLinkedSourceUpgradeParameters
from delphixpy.web.objects.AggregateCapacityData import AggregateCapacityData
from delphixpy.web.objects.HostPrivilegeElevationProfileScript import HostPrivilegeElevationProfileScript
from delphixpy.web.objects.MSSqlBaseClusterRepository import MSSqlBaseClusterRepository
from delphixpy.web.objects.OracleBaseLinkData import OracleBaseLinkData
from delphixpy.web.objects.JSTimelinePointTimeInput import JSTimelinePointTimeInput
from delphixpy.web.objects.PgSQLTimeflowPoint import PgSQLTimeflowPoint
from delphixpy.web.objects.ASELinkedSource import ASELinkedSource
from delphixpy.web.objects.MSSqlAttachData import MSSqlAttachData
from delphixpy.web.objects.CurrentGroupCapacityData import CurrentGroupCapacityData
from delphixpy.web.objects.AppDataStagedLinkData import AppDataStagedLinkData
from delphixpy.web.objects.NetworkLatencyTestParameters import NetworkLatencyTestParameters
from delphixpy.web.objects.DSPAutotunerParameters import DSPAutotunerParameters
from delphixpy.web.objects.LuaEventBundle import LuaEventBundle
from delphixpy.web.objects.RunMaskingJobOperation import RunMaskingJobOperation
from delphixpy.web.objects.MSSqlNewCopyOnlyFullBackupSyncParameters import MSSqlNewCopyOnlyFullBackupSyncParameters
from delphixpy.web.objects.Schedule import Schedule
from delphixpy.web.objects.TimeflowPointTimestamp import TimeflowPointTimestamp
from delphixpy.web.objects.SshVerifyRawKey import SshVerifyRawKey
from delphixpy.web.objects.X500DistinguishedNameFields import X500DistinguishedNameFields
from delphixpy.web.objects.OracleInstance import OracleInstance
from delphixpy.web.objects.DxFsIoQueueOpsDatapointStream import DxFsIoQueueOpsDatapointStream
from delphixpy.web.objects.ListResult import ListResult
from delphixpy.web.objects.Json import Json
from delphixpy.web.objects.PgSQLHBAEntry import PgSQLHBAEntry
from delphixpy.web.objects.ErrorResult import ErrorResult
from delphixpy.web.objects.ToolkitUpgradeDefinition import ToolkitUpgradeDefinition
from delphixpy.web.objects.HistoricalGroupCapacityData import HistoricalGroupCapacityData
from delphixpy.web.objects.VMwareSourceRuntime import VMwareSourceRuntime
from delphixpy.web.objects.Source import Source
from delphixpy.web.objects.KerberosCredential import KerberosCredential
from delphixpy.web.objects.LdapInfo import LdapInfo
from delphixpy.web.objects.PgSQLLinkedSource import PgSQLLinkedSource
from delphixpy.web.objects.ConnectivityParameters import ConnectivityParameters
from delphixpy.web.objects.TargetOwnerFilter import TargetOwnerFilter
from delphixpy.web.objects.CompatibilityCriteria import CompatibilityCriteria
from delphixpy.web.objects.AppDataCachedMountPoint import AppDataCachedMountPoint
from delphixpy.web.objects.AppDataLinkedSource import AppDataLinkedSource
from delphixpy.web.objects.TypedObject import TypedObject
from delphixpy.web.objects.OracleMissingLog import OracleMissingLog
from delphixpy.web.objects.MSSqlSyncParameters import MSSqlSyncParameters
from delphixpy.web.objects.OracleSIConfig import OracleSIConfig
from delphixpy.web.objects.UserInterfaceConfig import UserInterfaceConfig
from delphixpy.web.objects.IntegerGreaterThanConstraint import IntegerGreaterThanConstraint
from delphixpy.web.objects.OraclePlatformParameters import OraclePlatformParameters
from delphixpy.web.objects.SnapshotCapacityData import SnapshotCapacityData
from delphixpy.web.objects.JSDataLayoutCreateParameters import JSDataLayoutCreateParameters
from delphixpy.web.objects.StatisticAxis import StatisticAxis
from delphixpy.web.objects.JSBookmarkCreateParameters import JSBookmarkCreateParameters
from delphixpy.web.objects.AppDataTimeflowPoint import AppDataTimeflowPoint
from delphixpy.web.objects.AppDataEmptyVFilesCreationParameters import AppDataEmptyVFilesCreationParameters
from delphixpy.web.objects.MSSqlFailoverClusterInstance import MSSqlFailoverClusterInstance
from delphixpy.web.objects.StorageTestParameters import StorageTestParameters
from delphixpy.web.objects.StringConstraint import StringConstraint
from delphixpy.web.objects.JSDataContainerCreateWithRefreshParameters import JSDataContainerCreateWithRefreshParameters
from delphixpy.web.objects.JSTimestampDataParent import JSTimestampDataParent
from delphixpy.web.objects.VirtualSourceOperations import VirtualSourceOperations
from delphixpy.web.objects.PathDescendantConstraint import PathDescendantConstraint
from delphixpy.web.objects.SystemInfo import SystemInfo
from delphixpy.web.objects.ScrubStatus import ScrubStatus
from delphixpy.web.objects.RunBashOnSourceOperation import RunBashOnSourceOperation
from delphixpy.web.objects.VMwareSource import VMwareSource
from delphixpy.web.objects.CapacityBreakdown import CapacityBreakdown
from delphixpy.web.objects.ASETimeflowPoint import ASETimeflowPoint
from delphixpy.web.objects.VMwareMachineConfig import VMwareMachineConfig
from delphixpy.web.objects.SourceDisableParameters import SourceDisableParameters
from delphixpy.web.objects.TimeflowRange import TimeflowRange
from delphixpy.web.objects.ASETimeflow import ASETimeflow
from delphixpy.web.objects.AppDataManagedSource import AppDataManagedSource
from delphixpy.web.objects.MSSqlClusterInstance import MSSqlClusterInstance
from delphixpy.web.objects.Operation import Operation
from delphixpy.web.objects.CertificateConfig import CertificateConfig
from delphixpy.web.objects.VMwarePlatformParameters import VMwarePlatformParameters
from delphixpy.web.objects.MSSqlAvailabilityGroupListener import MSSqlAvailabilityGroupListener
from delphixpy.web.objects.StagingCompatibilityParameters import StagingCompatibilityParameters
from delphixpy.web.objects.NetworkLatencyTest import NetworkLatencyTest
from delphixpy.web.objects.JSContainerUsageData import JSContainerUsageData
from delphixpy.web.objects.MySQLTimeflow import MySQLTimeflow
from delphixpy.web.objects.MySQLLinkData import MySQLLinkData
from delphixpy.web.objects.PolicyCreateAndApplyParameters import PolicyCreateAndApplyParameters
from delphixpy.web.objects.ResetIgnoredFaultsParameters import ResetIgnoredFaultsParameters
from delphixpy.web.objects.WindowsHost import WindowsHost
from delphixpy.web.objects.SourceConnectionInfo import SourceConnectionInfo
from delphixpy.web.objects.SourceStartParameters import SourceStartParameters
from delphixpy.web.objects.ProvisionCompatibilityParameters import ProvisionCompatibilityParameters
from delphixpy.web.objects.RegistrationInfo import RegistrationInfo
from delphixpy.web.objects.ASEStagingSource import ASEStagingSource
from delphixpy.web.objects.LinkData import LinkData
from delphixpy.web.objects.OracleRACSourceConnectionInfo import OracleRACSourceConnectionInfo
from delphixpy.web.objects.CpuUtilDatapoint import CpuUtilDatapoint
from delphixpy.web.objects.OracleCreateTransformationParameters import OracleCreateTransformationParameters
from delphixpy.web.objects.MySQLExportParameters import MySQLExportParameters
from delphixpy.web.objects.PgSQLIdentEntry import PgSQLIdentEntry
from delphixpy.web.objects.SyslogServer import SyslogServer
from delphixpy.web.objects.TimeflowBookmarkCreateParameters import TimeflowBookmarkCreateParameters
from delphixpy.web.objects.LoginRequest import LoginRequest
from delphixpy.web.objects.AppDataCreateTransformationParameters import AppDataCreateTransformationParameters
from delphixpy.web.objects.AppDataContainer import AppDataContainer
from delphixpy.web.objects.OracleBaseAttachData import OracleBaseAttachData
from delphixpy.web.objects.LocaleSettings import LocaleSettings
from delphixpy.web.objects.AppDataSnapshotRuntime import AppDataSnapshotRuntime
from delphixpy.web.objects.VMwareTimeflow import VMwareTimeflow
from delphixpy.web.objects.OracleSysauxDatafileSpecification import OracleSysauxDatafileSpecification
from delphixpy.web.objects.CertificateSigningRequestCreateParameters import CertificateSigningRequestCreateParameters
from delphixpy.web.objects.WindowsClusterCreateParameters import WindowsClusterCreateParameters
from delphixpy.web.objects.MSSqlCompatibilityCriteria import MSSqlCompatibilityCriteria
from delphixpy.web.objects.OracleCluster import OracleCluster
from delphixpy.web.objects.ASESourceRuntime import ASESourceRuntime
from delphixpy.web.objects.JSDataContainerCreateParameters import JSDataContainerCreateParameters
from delphixpy.web.objects.ReplicationSpecRuntime import ReplicationSpecRuntime
from delphixpy.web.objects.MySQLSnapshot import MySQLSnapshot
from delphixpy.web.objects.OracleService import OracleService
from delphixpy.web.objects.PluginManifest import PluginManifest
from delphixpy.web.objects.KerberosKDC import KerberosKDC
from delphixpy.web.objects.AppDataLinkedDirectSource import AppDataLinkedDirectSource
from delphixpy.web.objects.HostPrivilegeElevationSettings import HostPrivilegeElevationSettings
from delphixpy.web.objects.OracleVirtualIP import OracleVirtualIP
from delphixpy.web.objects.MySQLBinlogCoordinates import MySQLBinlogCoordinates
from delphixpy.web.objects.RegistrationStatus import RegistrationStatus
from delphixpy.web.objects.AppDataSourceConfig import AppDataSourceConfig
from delphixpy.web.objects.VersionInfo import VersionInfo
from delphixpy.web.objects.NoBackupIngestionStrategy import NoBackupIngestionStrategy
from delphixpy.web.objects.AttachSourceParameters import AttachSourceParameters
from delphixpy.web.objects.ReadonlyNamedUserObject import ReadonlyNamedUserObject
from delphixpy.web.objects.DatabaseTemplate import DatabaseTemplate
from delphixpy.web.objects.PluginLinkedStagedSourceDefinition import PluginLinkedStagedSourceDefinition
from delphixpy.web.objects.OracleSyncParameters import OracleSyncParameters
from delphixpy.web.objects.PgSQLCreateTransformationParameters import PgSQLCreateTransformationParameters
from delphixpy.web.objects.SecurityConfig import SecurityConfig
from delphixpy.web.objects.HistoricalSystemCapacityData import HistoricalSystemCapacityData
from delphixpy.web.objects.OracleLog import OracleLog
from delphixpy.web.objects.OracleStartParameters import OracleStartParameters
from delphixpy.web.objects.EndEntityCertificate import EndEntityCertificate
from delphixpy.web.objects.OracleUndoDatafileSpecification import OracleUndoDatafileSpecification
from delphixpy.web.objects.EventFilter import EventFilter
from delphixpy.web.objects.CPUInfo import CPUInfo
from delphixpy.web.objects.OracleRACConfig import OracleRACConfig
from delphixpy.web.objects.SourceRepository import SourceRepository
from delphixpy.web.objects.OrFilter import OrFilter
from delphixpy.web.objects.StatisticSlice import StatisticSlice
from delphixpy.web.objects.SamlServiceProvider import SamlServiceProvider
from delphixpy.web.objects.JSDataContainerLockParameters import JSDataContainerLockParameters
from delphixpy.web.objects.XppTargetStatus import XppTargetStatus
from delphixpy.web.objects.PhoneHomeService import PhoneHomeService
from delphixpy.web.objects.PgSQLExportParameters import PgSQLExportParameters
from delphixpy.web.objects.ExportParameters import ExportParameters
from delphixpy.web.objects.AppDataWindowsTimeflow import AppDataWindowsTimeflow
from delphixpy.web.objects.UpgradeCheckResultsVersionParameters import UpgradeCheckResultsVersionParameters
from delphixpy.web.objects.StorageDevice import StorageDevice
from delphixpy.web.objects.TimeflowFilesystemLayout import TimeflowFilesystemLayout
from delphixpy.web.objects.Group import Group
from delphixpy.web.objects.OracleLinkedSource import OracleLinkedSource
from delphixpy.web.objects.VerifyVersionParameters import VerifyVersionParameters
from delphixpy.web.objects.BaseConsumerCapacityData import BaseConsumerCapacityData
from delphixpy.web.objects.TracerouteInfo import TracerouteInfo
from delphixpy.web.objects.OracleStagingSourceParameters import OracleStagingSourceParameters
from delphixpy.web.objects.OracleExportAsmParameters import OracleExportAsmParameters
from delphixpy.web.objects.AppDataSource import AppDataSource
from delphixpy.web.objects.AppDataLinkData import AppDataLinkData
from delphixpy.web.objects.WorkflowFunctionDefinition import WorkflowFunctionDefinition
from delphixpy.web.objects.SystemStatus import SystemStatus
from delphixpy.web.objects.X500DistinguishedNameComposite import X500DistinguishedNameComposite
from delphixpy.web.objects.JSSourceDataTimestamp import JSSourceDataTimestamp
from delphixpy.web.objects.IntegerEqualConstraint import IntegerEqualConstraint
from delphixpy.web.objects.OracleManagedSource import OracleManagedSource
from delphixpy.web.objects.EcdsaKeyPair import EcdsaKeyPair
from delphixpy.web.objects.SupportBundleUploadParameters import SupportBundleUploadParameters
from delphixpy.web.objects.Schema import Schema
from delphixpy.web.objects.OracleStopParameters import OracleStopParameters
from delphixpy.web.objects.MySQLTimeflowPoint import MySQLTimeflowPoint
from delphixpy.web.objects.OracleProvisionParameters import OracleProvisionParameters
from delphixpy.web.objects.MSSqlTimeflow import MSSqlTimeflow
from delphixpy.web.objects.SchemaDraftV4 import SchemaDraftV4
from delphixpy.web.objects.OracleCustomEnvVar import OracleCustomEnvVar
from delphixpy.web.objects.VMwareProvisionParameters import VMwareProvisionParameters
from delphixpy.web.objects.OracleTimeflow import OracleTimeflow
from delphixpy.web.objects.JSTimelinePointTimeParameters import JSTimelinePointTimeParameters
from delphixpy.web.objects.JSTemplateUsageData import JSTemplateUsageData
from delphixpy.web.objects.QuotaPolicy import QuotaPolicy
from delphixpy.web.objects.AlertProfile import AlertProfile
from delphixpy.web.objects.RsaKeyPair import RsaKeyPair
from delphixpy.web.objects.VMwareVirtualSource import VMwareVirtualSource
from delphixpy.web.objects.KeyPair import KeyPair
from delphixpy.web.objects.UpgradeCheckResult import UpgradeCheckResult
from delphixpy.web.objects.DatapointSet import DatapointSet
from delphixpy.web.objects.OracleSnapshot import OracleSnapshot
from delphixpy.web.objects.RetentionPolicy import RetentionPolicy
from delphixpy.web.objects.OracleCustomEnvVarRACFile import OracleCustomEnvVarRACFile
from delphixpy.web.objects.MSSqlBaseClusterListener import MSSqlBaseClusterListener
from delphixpy.web.objects.TimeflowSnapshot import TimeflowSnapshot
from delphixpy.web.objects.JSDataContainerRestoreParameters import JSDataContainerRestoreParameters
from delphixpy.web.objects.AppDataBaseTimeflow import AppDataBaseTimeflow
from delphixpy.web.objects.MSSqlDBContainerRuntime import MSSqlDBContainerRuntime
from delphixpy.web.objects.UnixHostCreateParameters import UnixHostCreateParameters
from delphixpy.web.objects.VMwareContainerRuntime import VMwareContainerRuntime
from delphixpy.web.objects.AuthFilterResult import AuthFilterResult
from delphixpy.web.objects.JSOperation import JSOperation
from delphixpy.web.objects.VirtualDatasetCreationParameters import VirtualDatasetCreationParameters
from delphixpy.web.objects.VMwareContainer import VMwareContainer
from delphixpy.web.objects.RemoteDelphixEngineInfo import RemoteDelphixEngineInfo
from delphixpy.web.objects.MaskingServiceConfig import MaskingServiceConfig
from delphixpy.web.objects.MySQLXtraBackupSyncParameters import MySQLXtraBackupSyncParameters
from delphixpy.web.objects.CertificateSigningRequest import CertificateSigningRequest
from delphixpy.web.objects.AppDataPlatformParameters import AppDataPlatformParameters
from delphixpy.web.objects.DiagnosisResult import DiagnosisResult
from delphixpy.web.objects.SupportBundleGenerateParameters import SupportBundleGenerateParameters
from delphixpy.web.objects.JSDataSource import JSDataSource
from delphixpy.web.objects.SnapshotLogFetchParameters import SnapshotLogFetchParameters
from delphixpy.web.objects.JSDailyOperationDuration import JSDailyOperationDuration
from delphixpy.web.objects.MySQLInstall import MySQLInstall
from delphixpy.web.objects.NetbackupConnectivityParameters import NetbackupConnectivityParameters
from delphixpy.web.objects.SourceEnvironment import SourceEnvironment
from delphixpy.web.objects.DatapointStream import DatapointStream
from delphixpy.web.objects.MSSqlDBConfig import MSSqlDBConfig
from delphixpy.web.objects.APISession import APISession
from delphixpy.web.objects.CertificateUploadParameters import CertificateUploadParameters
from delphixpy.web.objects.AppDataDirectSourceConfig import AppDataDirectSourceConfig
from delphixpy.web.objects.VMwareCreateTransformationParameters import VMwareCreateTransformationParameters
from delphixpy.web.objects.OracleRefreshParameters import OracleRefreshParameters
from delphixpy.web.objects.OracleCustomEnvVarFile import OracleCustomEnvVarFile
from delphixpy.web.objects.SourceStopParameters import SourceStopParameters
from delphixpy.web.objects.PgSQLDBConfig import PgSQLDBConfig
from delphixpy.web.objects.ValidateSMTPParameters import ValidateSMTPParameters
from delphixpy.web.objects.PurgeLogsResult import PurgeLogsResult
from delphixpy.web.objects.TimeConfig import TimeConfig
from delphixpy.web.objects.SamlAuthParameters import SamlAuthParameters
from delphixpy.web.objects.Timeflow import Timeflow
from delphixpy.web.objects.SerializationPoint import SerializationPoint
from delphixpy.web.objects.SyncPolicy import SyncPolicy
from delphixpy.web.objects.SsoFailedLoginRecord import SsoFailedLoginRecord
from delphixpy.web.objects.SingletonUpdate import SingletonUpdate
from delphixpy.web.objects.MySQLDBContainerRuntime import MySQLDBContainerRuntime
from delphixpy.web.objects.TimeflowPointLocation import TimeflowPointLocation
from delphixpy.web.objects.SnapshotSpaceMap import SnapshotSpaceMap
from delphixpy.web.objects.BatchContainerRefreshParameters import BatchContainerRefreshParameters
from delphixpy.web.objects.DNSConfig import DNSConfig
from delphixpy.web.objects.UpgradeNotification import UpgradeNotification
from delphixpy.web.objects.MSSqlProvisionParameters import MSSqlProvisionParameters
from delphixpy.web.objects.OracleSourceConnectionInfo import OracleSourceConnectionInfo
from delphixpy.web.objects.StringEqualConstraint import StringEqualConstraint
from delphixpy.web.objects.MSSqlStagingSource import MSSqlStagingSource
from delphixpy.web.objects.OraclePDBAttachData import OraclePDBAttachData
from delphixpy.web.objects.SshVerifyBase import SshVerifyBase
from delphixpy.web.objects.NullConstraint import NullConstraint
from delphixpy.web.objects.NetworkInterfaceUtilDatapoint import NetworkInterfaceUtilDatapoint
from delphixpy.web.objects.LinkParameters import LinkParameters
from delphixpy.web.objects.StorageDeviceRemovalStatus import StorageDeviceRemovalStatus
from delphixpy.web.objects.BatchContainerDeleteParameters import BatchContainerDeleteParameters
from delphixpy.web.objects.ObjectNotification import ObjectNotification
from delphixpy.web.objects.FeatureFlagParameters import FeatureFlagParameters
from delphixpy.web.objects.EndEntityCertificateReplaceKeystoreParameters import EndEntityCertificateReplaceKeystoreParameters
from delphixpy.web.objects.UpgradeCompatibilityParameters import UpgradeCompatibilityParameters
from delphixpy.web.objects.SourceUpgradeParameters import SourceUpgradeParameters
from delphixpy.web.objects.TimeflowPoint import TimeflowPoint
from delphixpy.web.objects.SupportContact import SupportContact
from delphixpy.web.objects.SnapshotPolicy import SnapshotPolicy
from delphixpy.web.objects.MySQLVersion import MySQLVersion
from delphixpy.web.objects.ASESourceConnectionInfo import ASESourceConnectionInfo
from delphixpy.web.objects.ASEInstance import ASEInstance
from delphixpy.web.objects.TimeZone import TimeZone
from delphixpy.web.objects.NetworkDSPTest import NetworkDSPTest
from delphixpy.web.objects.EnumConstraint import EnumConstraint
from delphixpy.web.objects.CredentialUpdateParameters import CredentialUpdateParameters
from delphixpy.web.objects.OracleAddLiveSourceParameters import OracleAddLiveSourceParameters
from delphixpy.web.objects.SwitchTimeflowParameters import SwitchTimeflowParameters
from delphixpy.web.objects.VMwareSnapshot import VMwareSnapshot
from delphixpy.web.objects.NetworkTest import NetworkTest
from delphixpy.web.objects.ToolkitVirtualSource import ToolkitVirtualSource
from delphixpy.web.objects.PolicyApplyTargetParameters import PolicyApplyTargetParameters
from delphixpy.web.objects.OracleNodeListener import OracleNodeListener
from delphixpy.web.objects.TCPStatsDatapoint import TCPStatsDatapoint
from delphixpy.web.objects.JSDataParent import JSDataParent
from delphixpy.web.objects.ReplicationList import ReplicationList
from delphixpy.web.objects.PemCertificateChain import PemCertificateChain
from delphixpy.web.objects.BatchSnapshotDeleteParameters import BatchSnapshotDeleteParameters
from delphixpy.web.objects.TimeflowBookmark import TimeflowBookmark
from delphixpy.web.objects.VMwareAttachData import VMwareAttachData
from delphixpy.web.objects.OracleAttachData import OracleAttachData
from delphixpy.web.objects.OracleListener import OracleListener
from delphixpy.web.objects.OracleWarehouseSource import OracleWarehouseSource
from delphixpy.web.objects.JSDataChild import JSDataChild
from delphixpy.web.objects.KerberosConfig import KerberosConfig
from delphixpy.web.objects.VMwareHostCreateParameters import VMwareHostCreateParameters
from delphixpy.web.objects.FileMappingResult import FileMappingResult
from delphixpy.web.objects.OracleRACInstance import OracleRACInstance
from delphixpy.web.objects.PgSQLSourceRuntime import PgSQLSourceRuntime
from delphixpy.web.objects.AlertFilter import AlertFilter
from delphixpy.web.objects.ReplicationSecureList import ReplicationSecureList
from delphixpy.web.objects.JSDataContainerUndoParameters import JSDataContainerUndoParameters
from delphixpy.web.objects.MySQLSourceRuntime import MySQLSourceRuntime
from delphixpy.web.objects.MySQLNewMySQLDumpSyncParameters import MySQLNewMySQLDumpSyncParameters
from delphixpy.web.objects.ConnectorConnectivity import ConnectorConnectivity
from delphixpy.web.objects.VMwareLinkedSource import VMwareLinkedSource
from delphixpy.web.objects.ToolkitLinkedSource import ToolkitLinkedSource
from delphixpy.web.objects.JSOperationEndpoint import JSOperationEndpoint
from delphixpy.web.objects.JSBookmarkDataParent import JSBookmarkDataParent
from delphixpy.web.objects.TimeflowLogFetchParameters import TimeflowLogFetchParameters
from delphixpy.web.objects.MSSqlExistingMostRecentBackupSyncParameters import MSSqlExistingMostRecentBackupSyncParameters
from delphixpy.web.objects.ASEDBContainer import ASEDBContainer
from delphixpy.web.objects.Container import Container
from delphixpy.web.objects.NamespaceFailoverParameters import NamespaceFailoverParameters
from delphixpy.web.objects.PluginDiscoveryDefinition import PluginDiscoveryDefinition
from delphixpy.web.objects.PgSQLAttachData import PgSQLAttachData
from delphixpy.web.objects.PasswordCredential import PasswordCredential
from delphixpy.web.objects.StagingSourceOperations import StagingSourceOperations
from delphixpy.web.objects.OracleCustomEnvVarPair import OracleCustomEnvVarPair
from delphixpy.web.objects.CurrentSystemCapacityData import CurrentSystemCapacityData
from delphixpy.web.objects.FaultEffect import FaultEffect
from delphixpy.web.objects.SourceEnableParameters import SourceEnableParameters
from delphixpy.web.objects.AlertAction import AlertAction
from delphixpy.web.objects.ToolkitDiscoveryDefinition import ToolkitDiscoveryDefinition
from delphixpy.web.objects.OracleClusterNode import OracleClusterNode
from delphixpy.web.objects.EndEntityCertificateReplaceParameters import EndEntityCertificateReplaceParameters
from delphixpy.web.objects.RollbackParameters import RollbackParameters
from delphixpy.web.objects.TimeflowPointBookmark import TimeflowPointBookmark
from delphixpy.web.objects.PgSQLPlatformParameters import PgSQLPlatformParameters
from delphixpy.web.objects.OraclePDBLinkData import OraclePDBLinkData
from delphixpy.web.objects.CloudStatus import CloudStatus
from delphixpy.web.objects.JSDataContainerRefreshParameters import JSDataContainerRefreshParameters
from delphixpy.web.objects.VMwareComputeResource import VMwareComputeResource
from delphixpy.web.objects.DbExportParameters import DbExportParameters
from delphixpy.web.objects.OracleCompatibilityCriteria import OracleCompatibilityCriteria
from delphixpy.web.objects.NetworkDSPTestParameters import NetworkDSPTestParameters
from delphixpy.web.objects.ASEExportParameters import ASEExportParameters
from delphixpy.web.objects.JSDataTemplateCreateParameters import JSDataTemplateCreateParameters
from delphixpy.web.objects.ReplicationTargetState import ReplicationTargetState
from delphixpy.web.objects.SplunkHecConfig import SplunkHecConfig
from delphixpy.web.objects.MySQLSyncParameters import MySQLSyncParameters
from delphixpy.web.objects.AppDataLinkedStagedSource import AppDataLinkedStagedSource
from delphixpy.web.objects.AuthGetByPropertiesParameters import AuthGetByPropertiesParameters
from delphixpy.web.objects.TimeflowPointSemantic import TimeflowPointSemantic
from delphixpy.web.objects.OracleDBContainerRuntime import OracleDBContainerRuntime
from delphixpy.web.objects.ASESnapshot import ASESnapshot


try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str



#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-network-dsp-test-parameters.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_8_0.web.objects.NetworkThroughputTestBaseParameters import NetworkThroughputTestBaseParameters
from delphixpy.v1_8_0 import factory
from delphixpy.v1_8_0 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class NetworkDSPTestParameters(NetworkThroughputTestBaseParameters):
    """
    *(extends* :py:class:`v1_8_0.web.vo.NetworkThroughputTestBaseParameters`
    *)* Parameters used to execute a network throughput test using the Delphix
    Session Protocol.
    """
    def __init__(self, undef_enabled=True):
        super(NetworkDSPTestParameters, self).__init__()
        self._type = ("NetworkDSPTestParameters", True)
        self._compression = (self.__undef__, True)
        self._send_socket_buffer = (self.__undef__, True)
        self._encryption = (self.__undef__, True)
        self._remote_delphix_engine_info = (self.__undef__, True)
        self._block_size = (self.__undef__, True)
        self._queue_depth = (self.__undef__, True)
        self._destination_type = (self.__undef__, True)
        self._receive_socket_buffer = (self.__undef__, True)

    API_VERSION = "1.8.0"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(NetworkDSPTestParameters, cls).from_dict(data, dirty, undef_enabled)
        obj._compression = (data.get("compression", obj.__undef__), dirty)
        if obj._compression[0] is not None and obj._compression[0] is not obj.__undef__:
            assert isinstance(obj._compression[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._compression[0], type(obj._compression[0])))
            common.validate_format(obj._compression[0], "None", None, None)
        obj._send_socket_buffer = (data.get("sendSocketBuffer", obj.__undef__), dirty)
        if obj._send_socket_buffer[0] is not None and obj._send_socket_buffer[0] is not obj.__undef__:
            assert isinstance(obj._send_socket_buffer[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._send_socket_buffer[0], type(obj._send_socket_buffer[0])))
            common.validate_format(obj._send_socket_buffer[0], "None", None, None)
        obj._encryption = (data.get("encryption", obj.__undef__), dirty)
        if obj._encryption[0] is not None and obj._encryption[0] is not obj.__undef__:
            assert isinstance(obj._encryption[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._encryption[0], type(obj._encryption[0])))
            common.validate_format(obj._encryption[0], "None", None, None)
        if "remoteDelphixEngineInfo" in data and data["remoteDelphixEngineInfo"] is not None:
            obj._remote_delphix_engine_info = (factory.create_object(data["remoteDelphixEngineInfo"], "RemoteDelphixEngineInfo"), dirty)
            factory.validate_type(obj._remote_delphix_engine_info[0], "RemoteDelphixEngineInfo")
        else:
            obj._remote_delphix_engine_info = (obj.__undef__, dirty)
        obj._block_size = (data.get("blockSize", obj.__undef__), dirty)
        if obj._block_size[0] is not None and obj._block_size[0] is not obj.__undef__:
            assert isinstance(obj._block_size[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._block_size[0], type(obj._block_size[0])))
            common.validate_format(obj._block_size[0], "None", None, None)
        obj._queue_depth = (data.get("queueDepth", obj.__undef__), dirty)
        if obj._queue_depth[0] is not None and obj._queue_depth[0] is not obj.__undef__:
            assert isinstance(obj._queue_depth[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._queue_depth[0], type(obj._queue_depth[0])))
            common.validate_format(obj._queue_depth[0], "None", None, None)
        obj._destination_type = (data.get("destinationType", obj.__undef__), dirty)
        if obj._destination_type[0] is not None and obj._destination_type[0] is not obj.__undef__:
            assert isinstance(obj._destination_type[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._destination_type[0], type(obj._destination_type[0])))
            assert obj._destination_type[0] in [u'REMOTE_HOST', u'DELPHIX_ENGINE'], "Expected enum [u'REMOTE_HOST', u'DELPHIX_ENGINE'] but got %s" % obj._destination_type[0]
            common.validate_format(obj._destination_type[0], "None", None, None)
        obj._receive_socket_buffer = (data.get("receiveSocketBuffer", obj.__undef__), dirty)
        if obj._receive_socket_buffer[0] is not None and obj._receive_socket_buffer[0] is not obj.__undef__:
            assert isinstance(obj._receive_socket_buffer[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._receive_socket_buffer[0], type(obj._receive_socket_buffer[0])))
            common.validate_format(obj._receive_socket_buffer[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(NetworkDSPTestParameters, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "compression" == "type" or (self.compression is not self.__undef__ and (not (dirty and not self._compression[1]) or isinstance(self.compression, list) or belongs_to_parent)):
            dct["compression"] = dictify(self.compression)
        elif belongs_to_parent and self.compression is self.__undef__:
            dct["compression"] = False
        if "send_socket_buffer" == "type" or (self.send_socket_buffer is not self.__undef__ and (not (dirty and not self._send_socket_buffer[1]) or isinstance(self.send_socket_buffer, list) or belongs_to_parent)):
            dct["sendSocketBuffer"] = dictify(self.send_socket_buffer)
        elif belongs_to_parent and self.send_socket_buffer is self.__undef__:
            dct["sendSocketBuffer"] = 262144
        if "encryption" == "type" or (self.encryption is not self.__undef__ and (not (dirty and not self._encryption[1]) or isinstance(self.encryption, list) or belongs_to_parent)):
            dct["encryption"] = dictify(self.encryption)
        elif belongs_to_parent and self.encryption is self.__undef__:
            dct["encryption"] = False
        if "remote_delphix_engine_info" == "type" or (self.remote_delphix_engine_info is not self.__undef__ and (not (dirty and not self._remote_delphix_engine_info[1]) or isinstance(self.remote_delphix_engine_info, list) or belongs_to_parent)):
            dct["remoteDelphixEngineInfo"] = dictify(self.remote_delphix_engine_info, prop_is_list_or_vo=True)
        if "block_size" == "type" or (self.block_size is not self.__undef__ and (not (dirty and not self._block_size[1]) or isinstance(self.block_size, list) or belongs_to_parent)):
            dct["blockSize"] = dictify(self.block_size)
        elif belongs_to_parent and self.block_size is self.__undef__:
            dct["blockSize"] = 65536
        if "queue_depth" == "type" or (self.queue_depth is not self.__undef__ and (not (dirty and not self._queue_depth[1]) or isinstance(self.queue_depth, list) or belongs_to_parent)):
            dct["queueDepth"] = dictify(self.queue_depth)
        elif belongs_to_parent and self.queue_depth is self.__undef__:
            dct["queueDepth"] = 32
        if "destination_type" == "type" or (self.destination_type is not self.__undef__ and (not (dirty and not self._destination_type[1]) or isinstance(self.destination_type, list) or belongs_to_parent)):
            dct["destinationType"] = dictify(self.destination_type)
        elif belongs_to_parent and self.destination_type is self.__undef__:
            dct["destinationType"] = "REMOTE_HOST"
        if "receive_socket_buffer" == "type" or (self.receive_socket_buffer is not self.__undef__ and (not (dirty and not self._receive_socket_buffer[1]) or isinstance(self.receive_socket_buffer, list) or belongs_to_parent)):
            dct["receiveSocketBuffer"] = dictify(self.receive_socket_buffer)
        elif belongs_to_parent and self.receive_socket_buffer is self.__undef__:
            dct["receiveSocketBuffer"] = 262144
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._compression = (self._compression[0], True)
        self._send_socket_buffer = (self._send_socket_buffer[0], True)
        self._encryption = (self._encryption[0], True)
        self._remote_delphix_engine_info = (self._remote_delphix_engine_info[0], True)
        self._block_size = (self._block_size[0], True)
        self._queue_depth = (self._queue_depth[0], True)
        self._destination_type = (self._destination_type[0], True)
        self._receive_socket_buffer = (self._receive_socket_buffer[0], True)

    def is_dirty(self):
        return any([self._compression[1], self._send_socket_buffer[1], self._encryption[1], self._remote_delphix_engine_info[1], self._block_size[1], self._queue_depth[1], self._destination_type[1], self._receive_socket_buffer[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, NetworkDSPTestParameters):
            return False
        return super(NetworkDSPTestParameters, self).__eq__(other) and \
               self.compression == other.compression and \
               self.send_socket_buffer == other.send_socket_buffer and \
               self.encryption == other.encryption and \
               self.remote_delphix_engine_info == other.remote_delphix_engine_info and \
               self.block_size == other.block_size and \
               self.queue_depth == other.queue_depth and \
               self.destination_type == other.destination_type and \
               self.receive_socket_buffer == other.receive_socket_buffer

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def compression(self):
        """
        Whether or not compression is used for the test.

        :rtype: ``bool``
        """
        return self._compression[0]

    @compression.setter
    def compression(self, value):
        self._compression = (value, True)

    @property
    def send_socket_buffer(self):
        """
        *(default value: 262144)* The size of the send socket buffer in bytes.

        :rtype: ``int``
        """
        return self._send_socket_buffer[0]

    @send_socket_buffer.setter
    def send_socket_buffer(self, value):
        self._send_socket_buffer = (value, True)

    @property
    def encryption(self):
        """
        Whether or not encryption is used for the test.

        :rtype: ``bool``
        """
        return self._encryption[0]

    @encryption.setter
    def encryption(self, value):
        self._encryption = (value, True)

    @property
    def remote_delphix_engine_info(self):
        """
        Address, username and password used when running a test to another
        Delphix Engine.

        :rtype: :py:class:`v1_8_0.web.vo.RemoteDelphixEngineInfo`
        """
        return self._remote_delphix_engine_info[0]

    @remote_delphix_engine_info.setter
    def remote_delphix_engine_info(self, value):
        self._remote_delphix_engine_info = (value, True)

    @property
    def block_size(self):
        """
        *(default value: 65536)* The size of each transmit request in bytes.

        :rtype: ``int``
        """
        return self._block_size[0]

    @block_size.setter
    def block_size(self, value):
        self._block_size = (value, True)

    @property
    def queue_depth(self):
        """
        *(default value: 32)* The queue depth used for the DSP throughput test.

        :rtype: ``int``
        """
        return self._queue_depth[0]

    @queue_depth.setter
    def queue_depth(self, value):
        self._queue_depth = (value, True)

    @property
    def destination_type(self):
        """
        *(default value: REMOTE_HOST)* Whether the test is testing connectivity
        to a Delphix Engine or remote host. *(permitted values: REMOTE_HOST,
        DELPHIX_ENGINE)*

        :rtype: ``TEXT_TYPE``
        """
        return self._destination_type[0]

    @destination_type.setter
    def destination_type(self, value):
        self._destination_type = (value, True)

    @property
    def receive_socket_buffer(self):
        """
        *(default value: 262144)* The size of the receive socket buffer in
        bytes.

        :rtype: ``int``
        """
        return self._receive_socket_buffer[0]

    @receive_socket_buffer.setter
    def receive_socket_buffer(self, value):
        self._receive_socket_buffer = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-network-route.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_7_0.web.objects.TypedObject import TypedObject
from delphixpy.v1_7_0 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class NetworkRoute(TypedObject):
    """
    *(extends* :py:class:`v1_7_0.web.vo.TypedObject` *)* IP routing table.
    """
    def __init__(self, undef_enabled=True):
        super(NetworkRoute, self).__init__()
        self._type = ("NetworkRoute", True)
        self._node = (self.__undef__, True)
        self._out_interface = (self.__undef__, True)
        self._destination = (self.__undef__, True)
        self._gateway = (self.__undef__, True)

    API_VERSION = "1.7.0"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(NetworkRoute, cls).from_dict(data, dirty, undef_enabled)
        obj._node = (data.get("node", obj.__undef__), dirty)
        if obj._node[0] is not None and obj._node[0] is not obj.__undef__:
            assert isinstance(obj._node[0], TEXT_TYPE), ("Expected one of [u'string', u'null'], but got %s of type %s" % (obj._node[0], type(obj._node[0])))
            common.validate_format(obj._node[0], "objectReference", None, None)
        obj._out_interface = (data.get("outInterface", obj.__undef__), dirty)
        if obj._out_interface[0] is not None and obj._out_interface[0] is not obj.__undef__:
            assert isinstance(obj._out_interface[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._out_interface[0], type(obj._out_interface[0])))
            common.validate_format(obj._out_interface[0], "objectReference", None, None)
        obj._destination = (data.get("destination", obj.__undef__), dirty)
        if obj._destination[0] is not None and obj._destination[0] is not obj.__undef__:
            assert isinstance(obj._destination[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._destination[0], type(obj._destination[0])))
            common.validate_format(obj._destination[0], "routeDestination", None, None)
        obj._gateway = (data.get("gateway", obj.__undef__), dirty)
        if obj._gateway[0] is not None and obj._gateway[0] is not obj.__undef__:
            assert isinstance(obj._gateway[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._gateway[0], type(obj._gateway[0])))
            common.validate_format(obj._gateway[0], "ipAddress", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(NetworkRoute, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "node" == "type" or (self.node is not self.__undef__ and (not (dirty and not self._node[1]) or isinstance(self.node, list) or belongs_to_parent)):
            dct["node"] = dictify(self.node)
        if "out_interface" == "type" or (self.out_interface is not self.__undef__ and (not (dirty and not self._out_interface[1]) or isinstance(self.out_interface, list) or belongs_to_parent)):
            dct["outInterface"] = dictify(self.out_interface)
        if "destination" == "type" or (self.destination is not self.__undef__ and (not (dirty and not self._destination[1]) or isinstance(self.destination, list) or belongs_to_parent)):
            dct["destination"] = dictify(self.destination)
        if "gateway" == "type" or (self.gateway is not self.__undef__ and (not (dirty and not self._gateway[1]) or isinstance(self.gateway, list) or belongs_to_parent)):
            dct["gateway"] = dictify(self.gateway)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._node = (self._node[0], True)
        self._out_interface = (self._out_interface[0], True)
        self._destination = (self._destination[0], True)
        self._gateway = (self._gateway[0], True)

    def is_dirty(self):
        return any([self._node[1], self._out_interface[1], self._destination[1], self._gateway[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, NetworkRoute):
            return False
        return super(NetworkRoute, self).__eq__(other) and \
               self.node == other.node and \
               self.out_interface == other.out_interface and \
               self.destination == other.destination and \
               self.gateway == other.gateway

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def node(self):
        """
        The node where this route exists.

        :rtype: ``TEXT_TYPE`` *or* ``null``
        """
        return self._node[0]

    @node.setter
    def node(self, value):
        self._node = (value, True)

    @property
    def out_interface(self):
        """
        Output interface to use for the route.

        :rtype: ``TEXT_TYPE``
        """
        return self._out_interface[0]

    @out_interface.setter
    def out_interface(self, value):
        self._out_interface = (value, True)

    @property
    def destination(self):
        """
        Destination for the route in Classless Inter-Domain Routing (CIDR)
        notation or the keyword 'default'.

        :rtype: ``TEXT_TYPE``
        """
        return self._destination[0]

    @destination.setter
    def destination(self, value):
        self._destination = (value, True)

    @property
    def gateway(self):
        """
        Next hop for the route.

        :rtype: ``TEXT_TYPE``
        """
        return self._gateway[0]

    @gateway.setter
    def gateway(self, value):
        self._gateway = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-replication-source-state.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_9_2.web.objects.UserObject import UserObject
from delphixpy.v1_9_2 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class ReplicationSourceState(UserObject):
    """
    *(extends* :py:class:`v1_9_2.web.vo.UserObject` *)* State of a replication
    spec.
    """
    def __init__(self, undef_enabled=True):
        super(ReplicationSourceState, self).__init__()
        self._type = ("ReplicationSourceState", True)
        self._last_point = (self.__undef__, True)
        self._spec = (self.__undef__, True)
        self._active_point = (self.__undef__, True)

    API_VERSION = "1.9.2"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(ReplicationSourceState, cls).from_dict(data, dirty, undef_enabled)
        obj._last_point = (data.get("lastPoint", obj.__undef__), dirty)
        if obj._last_point[0] is not None and obj._last_point[0] is not obj.__undef__:
            assert isinstance(obj._last_point[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._last_point[0], type(obj._last_point[0])))
            common.validate_format(obj._last_point[0], "objectReference", None, None)
        obj._spec = (data.get("spec", obj.__undef__), dirty)
        if obj._spec[0] is not None and obj._spec[0] is not obj.__undef__:
            assert isinstance(obj._spec[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._spec[0], type(obj._spec[0])))
            common.validate_format(obj._spec[0], "objectReference", None, None)
        obj._active_point = (data.get("activePoint", obj.__undef__), dirty)
        if obj._active_point[0] is not None and obj._active_point[0] is not obj.__undef__:
            assert isinstance(obj._active_point[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._active_point[0], type(obj._active_point[0])))
            common.validate_format(obj._active_point[0], "objectReference", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(ReplicationSourceState, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "last_point" == "type" or (self.last_point is not self.__undef__ and (not (dirty and not self._last_point[1]))):
            dct["lastPoint"] = dictify(self.last_point)
        if "spec" == "type" or (self.spec is not self.__undef__ and (not (dirty and not self._spec[1]))):
            dct["spec"] = dictify(self.spec)
        if "active_point" == "type" or (self.active_point is not self.__undef__ and (not (dirty and not self._active_point[1]))):
            dct["activePoint"] = dictify(self.active_point)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._last_point = (self._last_point[0], True)
        self._spec = (self._spec[0], True)
        self._active_point = (self._active_point[0], True)

    def is_dirty(self):
        return any([self._last_point[1], self._spec[1], self._active_point[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, ReplicationSourceState):
            return False
        return super(ReplicationSourceState, self).__eq__(other) and \
               self.last_point == other.last_point and \
               self.spec == other.spec and \
               self.active_point == other.active_point

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def last_point(self):
        """
        The last serialization point sent. This can be null prior to the first
        replication run.

        :rtype: ``TEXT_TYPE``
        """
        return self._last_point[0]

    @last_point.setter
    def last_point(self, value):
        self._last_point = (value, True)

    @property
    def spec(self):
        """
        A reference to the replication specification responsible for the
        current state.

        :rtype: ``TEXT_TYPE``
        """
        return self._spec[0]

    @spec.setter
    def spec(self, value):
        self._spec = (value, True)

    @property
    def active_point(self):
        """
        The active serialization point, currently being sent or about to be
        sent to replication targets.

        :rtype: ``TEXT_TYPE``
        """
        return self._active_point[0]

    @active_point.setter
    def active_point(self, value):
        self._active_point = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-analytics-io-ops-datapoint.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_7_1.web.objects.Datapoint import Datapoint
from delphixpy.v1_7_1 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class IoOpsDatapoint(Datapoint):
    """
    *(extends* :py:class:`v1_7_1.web.vo.Datapoint` *)* An analytics datapoint
    generated by the DISK_OPS, DxFS_OPS, DxFS_IO_QUEUE_OPS, iSCSI_OPS, NFS_OPS,
    or VFS_OPS statistic types.
    """
    def __init__(self, undef_enabled=True):
        super(IoOpsDatapoint, self).__init__()
        self._type = ("IoOpsDatapoint", True)
        self._count = (self.__undef__, True)
        self._latency = (self.__undef__, True)
        self._avg_latency = (self.__undef__, True)
        self._throughput = (self.__undef__, True)
        self._size = (self.__undef__, True)

    API_VERSION = "1.7.1"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(IoOpsDatapoint, cls).from_dict(data, dirty, undef_enabled)
        obj._count = (data.get("count", obj.__undef__), dirty)
        if obj._count[0] is not None and obj._count[0] is not obj.__undef__:
            assert isinstance(obj._count[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._count[0], type(obj._count[0])))
            common.validate_format(obj._count[0], "None", None, None)
        obj._latency = (data.get("latency", obj.__undef__), dirty)
        if obj._latency[0] is not None and obj._latency[0] is not obj.__undef__:
            assert isinstance(obj._latency[0], dict), ("Expected one of [u'object'], but got %s of type %s" % (obj._latency[0], type(obj._latency[0])))
            common.validate_format(obj._latency[0], "None", None, None)
        obj._avg_latency = (data.get("avgLatency", obj.__undef__), dirty)
        if obj._avg_latency[0] is not None and obj._avg_latency[0] is not obj.__undef__:
            assert isinstance(obj._avg_latency[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._avg_latency[0], type(obj._avg_latency[0])))
            common.validate_format(obj._avg_latency[0], "None", None, None)
        obj._throughput = (data.get("throughput", obj.__undef__), dirty)
        if obj._throughput[0] is not None and obj._throughput[0] is not obj.__undef__:
            assert isinstance(obj._throughput[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._throughput[0], type(obj._throughput[0])))
            common.validate_format(obj._throughput[0], "None", None, None)
        obj._size = (data.get("size", obj.__undef__), dirty)
        if obj._size[0] is not None and obj._size[0] is not obj.__undef__:
            assert isinstance(obj._size[0], dict), ("Expected one of [u'object'], but got %s of type %s" % (obj._size[0], type(obj._size[0])))
            common.validate_format(obj._size[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(IoOpsDatapoint, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "count" == "type" or (self.count is not self.__undef__ and (not (dirty and not self._count[1]))):
            dct["count"] = dictify(self.count)
        if "latency" == "type" or (self.latency is not self.__undef__ and (not (dirty and not self._latency[1]))):
            dct["latency"] = dictify(self.latency)
        if "avg_latency" == "type" or (self.avg_latency is not self.__undef__ and (not (dirty and not self._avg_latency[1]))):
            dct["avgLatency"] = dictify(self.avg_latency)
        if "throughput" == "type" or (self.throughput is not self.__undef__ and (not (dirty and not self._throughput[1]))):
            dct["throughput"] = dictify(self.throughput)
        if "size" == "type" or (self.size is not self.__undef__ and (not (dirty and not self._size[1]))):
            dct["size"] = dictify(self.size)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._count = (self._count[0], True)
        self._latency = (self._latency[0], True)
        self._avg_latency = (self._avg_latency[0], True)
        self._throughput = (self._throughput[0], True)
        self._size = (self._size[0], True)

    def is_dirty(self):
        return any([self._count[1], self._latency[1], self._avg_latency[1], self._throughput[1], self._size[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, IoOpsDatapoint):
            return False
        return super(IoOpsDatapoint, self).__eq__(other) and \
               self.count == other.count and \
               self.latency == other.latency and \
               self.avg_latency == other.avg_latency and \
               self.throughput == other.throughput and \
               self.size == other.size

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def count(self):
        """
        Number of I/O operations.

        :rtype: ``int``
        """
        return self._count[0]

    @count.setter
    def count(self, value):
        self._count = (value, True)

    @property
    def latency(self):
        """
        I/O latencies in nanoseconds.

        :rtype: ``dict``
        """
        return self._latency[0]

    @latency.setter
    def latency(self, value):
        self._latency = (value, True)

    @property
    def avg_latency(self):
        """
        Average I/O latency in nanoseconds.

        :rtype: ``int``
        """
        return self._avg_latency[0]

    @avg_latency.setter
    def avg_latency(self, value):
        self._avg_latency = (value, True)

    @property
    def throughput(self):
        """
        I/O throughput in bytes.

        :rtype: ``int``
        """
        return self._throughput[0]

    @throughput.setter
    def throughput(self, value):
        self._throughput = (value, True)

    @property
    def size(self):
        """
        I/O sizes in bytes.

        :rtype: ``dict``
        """
        return self._size[0]

    @size.setter
    def size(self, value):
        self._size = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-js-operation.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_4_0.web.objects.NamedUserObject import NamedUserObject
from delphixpy.v1_4_0 import factory
from delphixpy.v1_4_0 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class JSOperation(NamedUserObject):
    """
    *(extends* :py:class:`v1_4_0.web.vo.NamedUserObject` *)* An operation that
    occurred on a Jet Stream data layout.
    """
    def __init__(self, undef_enabled=True):
        super(JSOperation, self).__init__()
        self._type = ("JSOperation", True)
        self._data_layout = (self.__undef__, True)
        self._data_parent = (self.__undef__, True)
        self._data_time = (self.__undef__, True)
        self._description = (self.__undef__, True)
        self._bookmark = (self.__undef__, True)
        self._root_action = (self.__undef__, True)
        self._start_time = (self.__undef__, True)
        self._branch = (self.__undef__, True)
        self._operation = (self.__undef__, True)
        self._end_time = (self.__undef__, True)

    API_VERSION = "1.4.0"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(JSOperation, cls).from_dict(data, dirty, undef_enabled)
        obj._data_layout = (data.get("dataLayout", obj.__undef__), dirty)
        if obj._data_layout[0] is not None and obj._data_layout[0] is not obj.__undef__:
            assert isinstance(obj._data_layout[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._data_layout[0], type(obj._data_layout[0])))
            common.validate_format(obj._data_layout[0], "objectReference", None, None)
        if "dataParent" in data and data["dataParent"] is not None:
            obj._data_parent = (factory.create_object(data["dataParent"], "JSDataParent"), dirty)
            factory.validate_type(obj._data_parent[0], "JSDataParent")
        else:
            obj._data_parent = (obj.__undef__, dirty)
        obj._data_time = (data.get("dataTime", obj.__undef__), dirty)
        if obj._data_time[0] is not None and obj._data_time[0] is not obj.__undef__:
            assert isinstance(obj._data_time[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._data_time[0], type(obj._data_time[0])))
            common.validate_format(obj._data_time[0], "date", None, None)
        obj._description = (data.get("description", obj.__undef__), dirty)
        if obj._description[0] is not None and obj._description[0] is not obj.__undef__:
            assert isinstance(obj._description[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._description[0], type(obj._description[0])))
            common.validate_format(obj._description[0], "None", None, None)
        obj._bookmark = (data.get("bookmark", obj.__undef__), dirty)
        if obj._bookmark[0] is not None and obj._bookmark[0] is not obj.__undef__:
            assert isinstance(obj._bookmark[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._bookmark[0], type(obj._bookmark[0])))
            common.validate_format(obj._bookmark[0], "objectReference", None, None)
        obj._root_action = (data.get("rootAction", obj.__undef__), dirty)
        if obj._root_action[0] is not None and obj._root_action[0] is not obj.__undef__:
            assert isinstance(obj._root_action[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._root_action[0], type(obj._root_action[0])))
            common.validate_format(obj._root_action[0], "objectReference", None, None)
        obj._start_time = (data.get("startTime", obj.__undef__), dirty)
        if obj._start_time[0] is not None and obj._start_time[0] is not obj.__undef__:
            assert isinstance(obj._start_time[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._start_time[0], type(obj._start_time[0])))
            common.validate_format(obj._start_time[0], "date", None, None)
        obj._branch = (data.get("branch", obj.__undef__), dirty)
        if obj._branch[0] is not None and obj._branch[0] is not obj.__undef__:
            assert isinstance(obj._branch[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._branch[0], type(obj._branch[0])))
            common.validate_format(obj._branch[0], "objectReference", None, None)
        obj._operation = (data.get("operation", obj.__undef__), dirty)
        if obj._operation[0] is not None and obj._operation[0] is not obj.__undef__:
            assert isinstance(obj._operation[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._operation[0], type(obj._operation[0])))
            common.validate_format(obj._operation[0], "None", None, None)
        obj._end_time = (data.get("endTime", obj.__undef__), dirty)
        if obj._end_time[0] is not None and obj._end_time[0] is not obj.__undef__:
            assert isinstance(obj._end_time[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._end_time[0], type(obj._end_time[0])))
            common.validate_format(obj._end_time[0], "date", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(JSOperation, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "data_layout" == "type" or (self.data_layout is not self.__undef__ and (not (dirty and not self._data_layout[1]))):
            dct["dataLayout"] = dictify(self.data_layout)
        if "data_parent" == "type" or (self.data_parent is not self.__undef__ and (not (dirty and not self._data_parent[1]))):
            dct["dataParent"] = dictify(self.data_parent)
        if "data_time" == "type" or (self.data_time is not self.__undef__ and (not (dirty and not self._data_time[1]))):
            dct["dataTime"] = dictify(self.data_time)
        if "description" == "type" or (self.description is not self.__undef__ and (not (dirty and not self._description[1]))):
            dct["description"] = dictify(self.description)
        if "bookmark" == "type" or (self.bookmark is not self.__undef__ and (not (dirty and not self._bookmark[1]))):
            dct["bookmark"] = dictify(self.bookmark)
        if "root_action" == "type" or (self.root_action is not self.__undef__ and (not (dirty and not self._root_action[1]))):
            dct["rootAction"] = dictify(self.root_action)
        if "start_time" == "type" or (self.start_time is not self.__undef__ and (not (dirty and not self._start_time[1]))):
            dct["startTime"] = dictify(self.start_time)
        if "branch" == "type" or (self.branch is not self.__undef__ and (not (dirty and not self._branch[1]))):
            dct["branch"] = dictify(self.branch)
        if "operation" == "type" or (self.operation is not self.__undef__ and (not (dirty and not self._operation[1]))):
            dct["operation"] = dictify(self.operation)
        if "end_time" == "type" or (self.end_time is not self.__undef__ and (not (dirty and not self._end_time[1]))):
            dct["endTime"] = dictify(self.end_time)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._data_layout = (self._data_layout[0], True)
        self._data_parent = (self._data_parent[0], True)
        self._data_time = (self._data_time[0], True)
        self._description = (self._description[0], True)
        self._bookmark = (self._bookmark[0], True)
        self._root_action = (self._root_action[0], True)
        self._start_time = (self._start_time[0], True)
        self._branch = (self._branch[0], True)
        self._operation = (self._operation[0], True)
        self._end_time = (self._end_time[0], True)

    def is_dirty(self):
        return any([self._data_layout[1], self._data_parent[1], self._data_time[1], self._description[1], self._bookmark[1], self._root_action[1], self._start_time[1], self._branch[1], self._operation[1], self._end_time[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, JSOperation):
            return False
        return super(JSOperation, self).__eq__(other) and \
               self.data_layout == other.data_layout and \
               self.data_parent == other.data_parent and \
               self.data_time == other.data_time and \
               self.description == other.description and \
               self.bookmark == other.bookmark and \
               self.root_action == other.root_action and \
               self.start_time == other.start_time and \
               self.branch == other.branch and \
               self.operation == other.operation and \
               self.end_time == other.end_time

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def data_layout(self):
        """
        The data layout that this operation was performed on.

        :rtype: ``TEXT_TYPE``
        """
        return self._data_layout[0]

    @data_layout.setter
    def data_layout(self, value):
        self._data_layout = (value, True)

    @property
    def data_parent(self):
        """
        The data parent of the operation.

        :rtype: :py:class:`v1_4_0.web.vo.JSDataParent`
        """
        return self._data_parent[0]

    @data_parent.setter
    def data_parent(self, value):
        self._data_parent = (value, True)

    @property
    def data_time(self):
        """
        The time that the data represented by this operation was active. It
        will be null if the operation is in progress.

        :rtype: ``TEXT_TYPE``
        """
        return self._data_time[0]

    @data_time.setter
    def data_time(self, value):
        self._data_time = (value, True)

    @property
    def description(self):
        """
        Plain text description of the operation.

        :rtype: ``TEXT_TYPE``
        """
        return self._description[0]

    @description.setter
    def description(self, value):
        self._description = (value, True)

    @property
    def bookmark(self):
        """
        The bookmark that was created.

        :rtype: ``TEXT_TYPE``
        """
        return self._bookmark[0]

    @bookmark.setter
    def bookmark(self, value):
        self._bookmark = (value, True)

    @property
    def root_action(self):
        """
        The root action that spawned this operation.

        :rtype: ``TEXT_TYPE``
        """
        return self._root_action[0]

    @root_action.setter
    def root_action(self, value):
        self._root_action = (value, True)

    @property
    def start_time(self):
        """
        The time the operation started.

        :rtype: ``TEXT_TYPE``
        """
        return self._start_time[0]

    @start_time.setter
    def start_time(self, value):
        self._start_time = (value, True)

    @property
    def branch(self):
        """
        The branch that this operation was performed on.

        :rtype: ``TEXT_TYPE``
        """
        return self._branch[0]

    @branch.setter
    def branch(self, value):
        self._branch = (value, True)

    @property
    def operation(self):
        """
        The operation performed. *(permitted values: REFRESH, RESET,
        CREATE_BRANCH, DELETE_BRANCH, CREATE_BOOKMARK, DELETE_BOOKMARK, ENABLE,
        DISABLE, ACTIVATE, DEACTIVATE, RECOVER, RESTORE)*

        :rtype: ``TEXT_TYPE``
        """
        return self._operation[0]

    @operation.setter
    def operation(self, value):
        self._operation = (value, True)

    @property
    def end_time(self):
        """
        The time the operation finished. It will be null if the operation is in
        progress.

        :rtype: ``TEXT_TYPE``
        """
        return self._end_time[0]

    @end_time.setter
    def end_time(self, value):
        self._end_time = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-timeflow.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_9_1.web.objects.NamedUserObject import NamedUserObject
from delphixpy.v1_9_1 import factory
from delphixpy.v1_9_1 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class Timeflow(NamedUserObject):
    """
    *(extends* :py:class:`v1_9_1.web.vo.NamedUserObject` *)* Data for a
    particular historical timeline within a database.
    """
    def __init__(self, undef_enabled=True):
        super(Timeflow, self).__init__()
        self._type = ("Timeflow", True)
        self._parent_point = (self.__undef__, True)
        self._parent_snapshot = (self.__undef__, True)
        self._container = (self.__undef__, True)
        self._creation_type = (self.__undef__, True)

    API_VERSION = "1.9.1"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(Timeflow, cls).from_dict(data, dirty, undef_enabled)
        if "parentPoint" in data and data["parentPoint"] is not None:
            obj._parent_point = (factory.create_object(data["parentPoint"], "TimeflowPoint"), dirty)
            factory.validate_type(obj._parent_point[0], "TimeflowPoint")
        else:
            obj._parent_point = (obj.__undef__, dirty)
        obj._parent_snapshot = (data.get("parentSnapshot", obj.__undef__), dirty)
        if obj._parent_snapshot[0] is not None and obj._parent_snapshot[0] is not obj.__undef__:
            assert isinstance(obj._parent_snapshot[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._parent_snapshot[0], type(obj._parent_snapshot[0])))
            common.validate_format(obj._parent_snapshot[0], "objectReference", None, None)
        obj._container = (data.get("container", obj.__undef__), dirty)
        if obj._container[0] is not None and obj._container[0] is not obj.__undef__:
            assert isinstance(obj._container[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._container[0], type(obj._container[0])))
            common.validate_format(obj._container[0], "objectReference", None, None)
        obj._creation_type = (data.get("creationType", obj.__undef__), dirty)
        if obj._creation_type[0] is not None and obj._creation_type[0] is not obj.__undef__:
            assert isinstance(obj._creation_type[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._creation_type[0], type(obj._creation_type[0])))
            assert obj._creation_type[0] in [u'INITIAL', u'INDETERMINATE', u'REFRESH', u'ROLLBACK', u'TEMPORARY', u'TRANSFORMATION', u'V2P', u'PDB_PLUG', u'WAREHOUSE', u'ORACLE_LIVE_SOURCE_RESYNC'], "Expected enum [u'INITIAL', u'INDETERMINATE', u'REFRESH', u'ROLLBACK', u'TEMPORARY', u'TRANSFORMATION', u'V2P', u'PDB_PLUG', u'WAREHOUSE', u'ORACLE_LIVE_SOURCE_RESYNC'] but got %s" % obj._creation_type[0]
            common.validate_format(obj._creation_type[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(Timeflow, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "parent_point" == "type" or (self.parent_point is not self.__undef__ and (not (dirty and not self._parent_point[1]))):
            dct["parentPoint"] = dictify(self.parent_point)
        if "parent_snapshot" == "type" or (self.parent_snapshot is not self.__undef__ and (not (dirty and not self._parent_snapshot[1]))):
            dct["parentSnapshot"] = dictify(self.parent_snapshot)
        if "container" == "type" or (self.container is not self.__undef__ and (not (dirty and not self._container[1]))):
            dct["container"] = dictify(self.container)
        if "creation_type" == "type" or (self.creation_type is not self.__undef__ and (not (dirty and not self._creation_type[1]))):
            dct["creationType"] = dictify(self.creation_type)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._parent_point = (self._parent_point[0], True)
        self._parent_snapshot = (self._parent_snapshot[0], True)
        self._container = (self._container[0], True)
        self._creation_type = (self._creation_type[0], True)

    def is_dirty(self):
        return any([self._parent_point[1], self._parent_snapshot[1], self._container[1], self._creation_type[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, Timeflow):
            return False
        return super(Timeflow, self).__eq__(other) and \
               self.parent_point == other.parent_point and \
               self.parent_snapshot == other.parent_snapshot and \
               self.container == other.container and \
               self.creation_type == other.creation_type

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def parent_point(self):
        """
        The origin point on the parent TimeFlow from which this TimeFlow was
        provisioned. This will not be present for TimeFlows derived from linked
        sources.

        :rtype: :py:class:`v1_9_1.web.vo.TimeflowPoint`
        """
        return self._parent_point[0]

    @parent_point.setter
    def parent_point(self, value):
        self._parent_point = (value, True)

    @property
    def parent_snapshot(self):
        """
        Reference to the parent snapshot that serves as the provisioning base
        for this object. This may be different from the snapshot within the
        parent point, and is only present for virtual TimeFlows.

        :rtype: ``TEXT_TYPE``
        """
        return self._parent_snapshot[0]

    @parent_snapshot.setter
    def parent_snapshot(self, value):
        self._parent_snapshot = (value, True)

    @property
    def container(self):
        """
        Reference to the data container (database) for this TimeFlow.

        :rtype: ``TEXT_TYPE``
        """
        return self._container[0]

    @container.setter
    def container(self, value):
        self._container = (value, True)

    @property
    def creation_type(self):
        """
        The source action that created the TimeFlow. *(permitted values:
        INITIAL, INDETERMINATE, REFRESH, ROLLBACK, TEMPORARY, TRANSFORMATION,
        V2P, PDB_PLUG, WAREHOUSE, ORACLE_LIVE_SOURCE_RESYNC)*

        :rtype: ``TEXT_TYPE``
        """
        return self._creation_type[0]

    @creation_type.setter
    def creation_type(self, value):
        self._creation_type = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_10_0.web.objects.TypedObject import TypedObject
from delphixpy.v1_10_0 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class LuaEventBundle(TypedObject):
    """
    *(extends* :py:class:`v1_10_0.web.vo.TypedObject` *)* An opaque type
    containing all information necessary to produce localized content from a
    toolkit.
    """
    def __init__(self, undef_enabled=True):
        super(LuaEventBundle, self).__init__()
        self._type = ("LuaEventBundle", True)
        self._toolkit_name = (self.__undef__, True)
        self._params = (self.__undef__, True)
        self._message_id = (self.__undef__, True)

    API_VERSION = "1.10.0"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(LuaEventBundle, cls).from_dict(data, dirty, undef_enabled)
        if "toolkitName" not in data:
            raise ValueError("Missing required property \"toolkitName\".")
        obj._toolkit_name = (data.get("toolkitName", obj.__undef__), dirty)
        if obj._toolkit_name[0] is not None and obj._toolkit_name[0] is not obj.__undef__:
            assert isinstance(obj._toolkit_name[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._toolkit_name[0], type(obj._toolkit_name[0])))
            common.validate_format(obj._toolkit_name[0], "None", None, None)
        if "params" not in data:
            raise ValueError("Missing required property \"params\".")
        obj._params = []
        for item in data.get("params") or []:
            assert isinstance(item, TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (item, type(item)))
            common.validate_format(item, "None", None, None)
            obj._params.append(item)
        obj._params = (obj._params, dirty)
        if "messageId" not in data:
            raise ValueError("Missing required property \"messageId\".")
        obj._message_id = (data.get("messageId", obj.__undef__), dirty)
        if obj._message_id[0] is not None and obj._message_id[0] is not obj.__undef__:
            assert isinstance(obj._message_id[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._message_id[0], type(obj._message_id[0])))
            common.validate_format(obj._message_id[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(LuaEventBundle, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "toolkit_name" == "type" or (self.toolkit_name is not self.__undef__ and (not (dirty and not self._toolkit_name[1]) or isinstance(self.toolkit_name, list) or belongs_to_parent)):
            dct["toolkitName"] = dictify(self.toolkit_name)
        if "params" == "type" or (self.params is not self.__undef__ and (not (dirty and not self._params[1]) or isinstance(self.params, list) or belongs_to_parent)):
            dct["params"] = dictify(self.params, prop_is_list_or_vo=True)
        if "message_id" == "type" or (self.message_id is not self.__undef__ and (not (dirty and not self._message_id[1]) or isinstance(self.message_id, list) or belongs_to_parent)):
            dct["messageId"] = dictify(self.message_id)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._toolkit_name = (self._toolkit_name[0], True)
        self._params = (self._params[0], True)
        self._message_id = (self._message_id[0], True)

    def is_dirty(self):
        return any([self._toolkit_name[1], self._params[1], self._message_id[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, LuaEventBundle):
            return False
        return super(LuaEventBundle, self).__eq__(other) and \
               self.toolkit_name == other.toolkit_name and \
               self.params == other.params and \
               self.message_id == other.message_id

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def toolkit_name(self):
        """
        The name of the toolkit that generated this event bundle.

        :rtype: ``TEXT_TYPE``
        """
        return self._toolkit_name[0]

    @toolkit_name.setter
    def toolkit_name(self, value):
        self._toolkit_name = (value, True)

    @property
    def params(self):
        """
        The parameter values to consume when this event bundle is localized.

        :rtype: ``list`` of ``TEXT_TYPE``
        """
        return self._params[0]

    @params.setter
    def params(self, value):
        self._params = (value, True)

    @property
    def message_id(self):
        """
        The unique identifier of the message in this event bundle.

        :rtype: ``TEXT_TYPE``
        """
        return self._message_id[0]

    @message_id.setter
    def message_id(self, value):
        self._message_id = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-container-utilization.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_10_1.web.objects.TypedObject import TypedObject
from delphixpy.v1_10_1 import factory
from delphixpy.v1_10_1 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class ContainerUtilization(TypedObject):
    """
    *(extends* :py:class:`v1_10_1.web.vo.TypedObject` *)* Represents the
    utilization of all containers during a particular period of time.
    """
    def __init__(self, undef_enabled=True):
        super(ContainerUtilization, self).__init__()
        self._type = ("ContainerUtilization", True)
        self._deleted = (self.__undef__, True)
        self._hidden = (self.__undef__, True)
        self._container = (self.__undef__, True)
        self._utilization = (self.__undef__, True)

    API_VERSION = "1.10.1"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(ContainerUtilization, cls).from_dict(data, dirty, undef_enabled)
        obj._deleted = (data.get("deleted", obj.__undef__), dirty)
        if obj._deleted[0] is not None and obj._deleted[0] is not obj.__undef__:
            assert isinstance(obj._deleted[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._deleted[0], type(obj._deleted[0])))
            common.validate_format(obj._deleted[0], "None", None, None)
        obj._hidden = (data.get("hidden", obj.__undef__), dirty)
        if obj._hidden[0] is not None and obj._hidden[0] is not obj.__undef__:
            assert isinstance(obj._hidden[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._hidden[0], type(obj._hidden[0])))
            common.validate_format(obj._hidden[0], "None", None, None)
        obj._container = (data.get("container", obj.__undef__), dirty)
        if obj._container[0] is not None and obj._container[0] is not obj.__undef__:
            assert isinstance(obj._container[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._container[0], type(obj._container[0])))
            common.validate_format(obj._container[0], "objectReference", None, None)
        obj._utilization = []
        for item in data.get("utilization") or []:
            obj._utilization.append(factory.create_object(item))
            factory.validate_type(obj._utilization[-1], "ContainerUtilizationInterval")
        obj._utilization = (obj._utilization, dirty)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(ContainerUtilization, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "deleted" == "type" or (self.deleted is not self.__undef__ and (not (dirty and not self._deleted[1]))):
            dct["deleted"] = dictify(self.deleted)
        if "hidden" == "type" or (self.hidden is not self.__undef__ and (not (dirty and not self._hidden[1]))):
            dct["hidden"] = dictify(self.hidden)
        if "container" == "type" or (self.container is not self.__undef__ and (not (dirty and not self._container[1]))):
            dct["container"] = dictify(self.container)
        if "utilization" == "type" or (self.utilization is not self.__undef__ and (not (dirty and not self._utilization[1]))):
            dct["utilization"] = dictify(self.utilization)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._deleted = (self._deleted[0], True)
        self._hidden = (self._hidden[0], True)
        self._container = (self._container[0], True)
        self._utilization = (self._utilization[0], True)

    def is_dirty(self):
        return any([self._deleted[1], self._hidden[1], self._container[1], self._utilization[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, ContainerUtilization):
            return False
        return super(ContainerUtilization, self).__eq__(other) and \
               self.deleted == other.deleted and \
               self.hidden == other.hidden and \
               self.container == other.container and \
               self.utilization == other.utilization

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def deleted(self):
        """
        True if this container has been deleted.

        :rtype: ``bool``
        """
        return self._deleted[0]

    @deleted.setter
    def deleted(self, value):
        self._deleted = (value, True)

    @property
    def hidden(self):
        """
        True if the current user does not have access to this container.

        :rtype: ``bool``
        """
        return self._hidden[0]

    @hidden.setter
    def hidden(self, value):
        self._hidden = (value, True)

    @property
    def container(self):
        """
        Reference to the container whose utilization we are describing.

        :rtype: ``TEXT_TYPE``
        """
        return self._container[0]

    @container.setter
    def container(self, value):
        self._container = (value, True)

    @property
    def utilization(self):
        """
        A list of container utilization statistics corresponding to this period
        of time, one for each sampling interval.

        :rtype: ``list`` of
            :py:class:`v1_10_1.web.vo.ContainerUtilizationInterval`
        """
        return self._utilization[0]

    @utilization.setter
    def utilization(self, value):
        self._utilization = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-password-policy.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_10_0.web.objects.NamedUserObject import NamedUserObject
from delphixpy.v1_10_0 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class PasswordPolicy(NamedUserObject):
    """
    *(extends* :py:class:`v1_10_0.web.vo.NamedUserObject` *)* Password policies
    for Delphix users.
    """
    def __init__(self, undef_enabled=True):
        super(PasswordPolicy, self).__init__()
        self._type = ("PasswordPolicy", True)
        self._digit = (self.__undef__, True)
        self._name = (self.__undef__, True)
        self._min_length = (self.__undef__, True)
        self._symbol = (self.__undef__, True)
        self._disallow_username_as_password = (self.__undef__, True)
        self._lowercase_letter = (self.__undef__, True)
        self._reuse_disallow_limit = (self.__undef__, True)
        self._uppercase_letter = (self.__undef__, True)

    API_VERSION = "1.10.0"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(PasswordPolicy, cls).from_dict(data, dirty, undef_enabled)
        obj._digit = (data.get("digit", obj.__undef__), dirty)
        if obj._digit[0] is not None and obj._digit[0] is not obj.__undef__:
            assert isinstance(obj._digit[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._digit[0], type(obj._digit[0])))
            common.validate_format(obj._digit[0], "None", None, None)
        obj._name = (data.get("name", obj.__undef__), dirty)
        if obj._name[0] is not None and obj._name[0] is not obj.__undef__:
            assert isinstance(obj._name[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._name[0], type(obj._name[0])))
            common.validate_format(obj._name[0], "None", 1, 64)
        obj._min_length = (data.get("minLength", obj.__undef__), dirty)
        if obj._min_length[0] is not None and obj._min_length[0] is not obj.__undef__:
            assert isinstance(obj._min_length[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._min_length[0], type(obj._min_length[0])))
            common.validate_format(obj._min_length[0], "None", None, None)
        obj._symbol = (data.get("symbol", obj.__undef__), dirty)
        if obj._symbol[0] is not None and obj._symbol[0] is not obj.__undef__:
            assert isinstance(obj._symbol[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._symbol[0], type(obj._symbol[0])))
            common.validate_format(obj._symbol[0], "None", None, None)
        obj._disallow_username_as_password = (data.get("disallowUsernameAsPassword", obj.__undef__), dirty)
        if obj._disallow_username_as_password[0] is not None and obj._disallow_username_as_password[0] is not obj.__undef__:
            assert isinstance(obj._disallow_username_as_password[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._disallow_username_as_password[0], type(obj._disallow_username_as_password[0])))
            common.validate_format(obj._disallow_username_as_password[0], "None", None, None)
        obj._lowercase_letter = (data.get("lowercaseLetter", obj.__undef__), dirty)
        if obj._lowercase_letter[0] is not None and obj._lowercase_letter[0] is not obj.__undef__:
            assert isinstance(obj._lowercase_letter[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._lowercase_letter[0], type(obj._lowercase_letter[0])))
            common.validate_format(obj._lowercase_letter[0], "None", None, None)
        obj._reuse_disallow_limit = (data.get("reuseDisallowLimit", obj.__undef__), dirty)
        if obj._reuse_disallow_limit[0] is not None and obj._reuse_disallow_limit[0] is not obj.__undef__:
            assert isinstance(obj._reuse_disallow_limit[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._reuse_disallow_limit[0], type(obj._reuse_disallow_limit[0])))
            common.validate_format(obj._reuse_disallow_limit[0], "None", None, None)
        obj._uppercase_letter = (data.get("uppercaseLetter", obj.__undef__), dirty)
        if obj._uppercase_letter[0] is not None and obj._uppercase_letter[0] is not obj.__undef__:
            assert isinstance(obj._uppercase_letter[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._uppercase_letter[0], type(obj._uppercase_letter[0])))
            common.validate_format(obj._uppercase_letter[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(PasswordPolicy, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "digit" == "type" or (self.digit is not self.__undef__ and (not (dirty and not self._digit[1]) or isinstance(self.digit, list) or belongs_to_parent)):
            dct["digit"] = dictify(self.digit)
        if "name" == "type" or (self.name is not self.__undef__ and (not (dirty and not self._name[1]) or isinstance(self.name, list) or belongs_to_parent)):
            dct["name"] = dictify(self.name)
        if "min_length" == "type" or (self.min_length is not self.__undef__ and (not (dirty and not self._min_length[1]) or isinstance(self.min_length, list) or belongs_to_parent)):
            dct["minLength"] = dictify(self.min_length)
        if "symbol" == "type" or (self.symbol is not self.__undef__ and (not (dirty and not self._symbol[1]) or isinstance(self.symbol, list) or belongs_to_parent)):
            dct["symbol"] = dictify(self.symbol)
        if "disallow_username_as_password" == "type" or (self.disallow_username_as_password is not self.__undef__ and (not (dirty and not self._disallow_username_as_password[1]) or isinstance(self.disallow_username_as_password, list) or belongs_to_parent)):
            dct["disallowUsernameAsPassword"] = dictify(self.disallow_username_as_password)
        if "lowercase_letter" == "type" or (self.lowercase_letter is not self.__undef__ and (not (dirty and not self._lowercase_letter[1]) or isinstance(self.lowercase_letter, list) or belongs_to_parent)):
            dct["lowercaseLetter"] = dictify(self.lowercase_letter)
        if "reuse_disallow_limit" == "type" or (self.reuse_disallow_limit is not self.__undef__ and (not (dirty and not self._reuse_disallow_limit[1]) or isinstance(self.reuse_disallow_limit, list) or belongs_to_parent)):
            dct["reuseDisallowLimit"] = dictify(self.reuse_disallow_limit)
        if "uppercase_letter" == "type" or (self.uppercase_letter is not self.__undef__ and (not (dirty and not self._uppercase_letter[1]) or isinstance(self.uppercase_letter, list) or belongs_to_parent)):
            dct["uppercaseLetter"] = dictify(self.uppercase_letter)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._digit = (self._digit[0], True)
        self._name = (self._name[0], True)
        self._min_length = (self._min_length[0], True)
        self._symbol = (self._symbol[0], True)
        self._disallow_username_as_password = (self._disallow_username_as_password[0], True)
        self._lowercase_letter = (self._lowercase_letter[0], True)
        self._reuse_disallow_limit = (self._reuse_disallow_limit[0], True)
        self._uppercase_letter = (self._uppercase_letter[0], True)

    def is_dirty(self):
        return any([self._digit[1], self._name[1], self._min_length[1], self._symbol[1], self._disallow_username_as_password[1], self._lowercase_letter[1], self._reuse_disallow_limit[1], self._uppercase_letter[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, PasswordPolicy):
            return False
        return super(PasswordPolicy, self).__eq__(other) and \
               self.digit == other.digit and \
               self.name == other.name and \
               self.min_length == other.min_length and \
               self.symbol == other.symbol and \
               self.disallow_username_as_password == other.disallow_username_as_password and \
               self.lowercase_letter == other.lowercase_letter and \
               self.reuse_disallow_limit == other.reuse_disallow_limit and \
               self.uppercase_letter == other.uppercase_letter

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def digit(self):
        """
        True if password must contain at least one digit.

        :rtype: ``bool``
        """
        return self._digit[0]

    @digit.setter
    def digit(self, value):
        self._digit = (value, True)

    @property
    def name(self):
        """
        Name of password policy.

        :rtype: ``TEXT_TYPE``
        """
        return self._name[0]

    @name.setter
    def name(self, value):
        self._name = (value, True)

    @property
    def min_length(self):
        """
        Minimum length for the password.

        :rtype: ``int``
        """
        return self._min_length[0]

    @min_length.setter
    def min_length(self, value):
        self._min_length = (value, True)

    @property
    def symbol(self):
        """
        True if password must contain at least one symbol.

        :rtype: ``bool``
        """
        return self._symbol[0]

    @symbol.setter
    def symbol(self, value):
        self._symbol = (value, True)

    @property
    def disallow_username_as_password(self):
        """
        True to disallow password containing username.

        :rtype: ``bool``
        """
        return self._disallow_username_as_password[0]

    @disallow_username_as_password.setter
    def disallow_username_as_password(self, value):
        self._disallow_username_as_password = (value, True)

    @property
    def lowercase_letter(self):
        """
        True if password must contain at least one lowercase letter.

        :rtype: ``bool``
        """
        return self._lowercase_letter[0]

    @lowercase_letter.setter
    def lowercase_letter(self, value):
        self._lowercase_letter = (value, True)

    @property
    def reuse_disallow_limit(self):
        """
        The password may not be the same as any of previous n passwords.

        :rtype: ``int``
        """
        return self._reuse_disallow_limit[0]

    @reuse_disallow_limit.setter
    def reuse_disallow_limit(self, value):
        self._reuse_disallow_limit = (value, True)

    @property
    def uppercase_letter(self):
        """
        True if password must contain at least one uppercase letter.

        :rtype: ``bool``
        """
        return self._uppercase_letter[0]

    @uppercase_letter.setter
    def uppercase_letter(self, value):
        self._uppercase_letter = (value, True)

